Class: XTwitterScraper::Models::ComposeCreateParams::Body::ComposePrepareRequest

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/x_twitter_scraper/models/compose_create_params.rb,
sig/x_twitter_scraper/models/compose_create_params.rbs

Defined Under Namespace

Modules: Goal

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(topic:, goal: nil, style_username: nil, step: :compose) ⇒ Object

Parameters:



# File 'lib/x_twitter_scraper/models/compose_create_params.rb', line 56

Instance Attribute Details

#goalSymbol, ...

Editorial goal used to order the rules and questions.



48
# File 'lib/x_twitter_scraper/models/compose_create_params.rb', line 48

optional :goal, enum: -> { XTwitterScraper::ComposeCreateParams::Body::ComposePrepareRequest::Goal }

#stepSymbol, :compose

Parameters:

  • value (:compose)

Returns:

  • (Symbol, :compose)


36
# File 'lib/x_twitter_scraper/models/compose_create_params.rb', line 36

required :step, const: :compose

#style_usernameString?

Username from a style analysis saved to this account.

Parameters:

  • (String)

Returns:

  • (String, nil)


54
# File 'lib/x_twitter_scraper/models/compose_create_params.rb', line 54

optional :style_username, String, api_name: :styleUsername

#topicString

Subject for the post.

Parameters:

  • value (String)

Returns:

  • (String)


42
# File 'lib/x_twitter_scraper/models/compose_create_params.rb', line 42

required :topic, String

Instance Method Details

#to_hash{

Returns:

  • ({)


65
# File 'sig/x_twitter_scraper/models/compose_create_params.rbs', line 65

def to_hash: -> {