Class: XTwitterScraper::Models::ContentDisclosure::AIGenerated
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- XTwitterScraper::Models::ContentDisclosure::AIGenerated
- Defined in:
- lib/x_twitter_scraper/models/content_disclosure.rb,
sig/x_twitter_scraper/models/content_disclosure.rbs
Overview
Instance Attribute Summary collapse
-
#can_edit ⇒ Boolean?
Whether the disclosure can be edited on X.
-
#detection_source ⇒ String?
Source of the AI-generated media disclosure.
-
#has_ai_generated_media ⇒ Boolean?
True when X labels the tweet as containing AI-generated media.
Instance Method Summary collapse
- #initialize(can_edit: nil, detection_source: nil, has_ai_generated_media: nil) ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(can_edit: nil, detection_source: nil, has_ai_generated_media: nil) ⇒ Object
|
|
# File 'lib/x_twitter_scraper/models/content_disclosure.rb', line 57
|
Instance Attribute Details
#can_edit ⇒ Boolean?
Whether the disclosure can be edited on X.
41 |
# File 'lib/x_twitter_scraper/models/content_disclosure.rb', line 41 optional :can_edit, XTwitterScraper::Internal::Type::Boolean, api_name: :canEdit |
#detection_source ⇒ String?
Source of the AI-generated media disclosure.
47 |
# File 'lib/x_twitter_scraper/models/content_disclosure.rb', line 47 optional :detection_source, String, api_name: :detectionSource |
#has_ai_generated_media ⇒ Boolean?
True when X labels the tweet as containing AI-generated media.
53 54 55 |
# File 'lib/x_twitter_scraper/models/content_disclosure.rb', line 53 optional :has_ai_generated_media, XTwitterScraper::Internal::Type::Boolean, api_name: :hasAiGeneratedMedia |
Instance Method Details
#to_hash ⇒ {
70 |
# File 'sig/x_twitter_scraper/models/content_disclosure.rbs', line 70
def to_hash: -> {
|