Class: XTwitterScraper::Models::ContentDisclosure::Advertising
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- XTwitterScraper::Models::ContentDisclosure::Advertising
- Defined in:
- lib/x_twitter_scraper/models/content_disclosure.rb,
sig/x_twitter_scraper/models/content_disclosure.rbs
Overview
Instance Attribute Summary collapse
-
#is_paid_promotion ⇒ Boolean?
True when X labels the tweet as paid promotion content.
Instance Method Summary collapse
-
#initialize ⇒ Advertising
constructor
A new instance of Advertising.
- #to_hash ⇒ { is_paid_promotion: bool }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Advertising
Returns a new instance of Advertising.
39 |
# File 'sig/x_twitter_scraper/models/content_disclosure.rbs', line 39
def initialize: (?is_paid_promotion: bool) -> void
|
Instance Attribute Details
#is_paid_promotion ⇒ Boolean?
True when X labels the tweet as paid promotion content.
29 |
# File 'lib/x_twitter_scraper/models/content_disclosure.rb', line 29 optional :is_paid_promotion, XTwitterScraper::Internal::Type::Boolean, api_name: :isPaidPromotion |
Instance Method Details
#to_hash ⇒ { is_paid_promotion: bool }
41 |
# File 'sig/x_twitter_scraper/models/content_disclosure.rbs', line 41
def to_hash: -> { is_paid_promotion: bool }
|