Class: XTwitterScraper::Models::CreditRetrieveBalanceResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- XTwitterScraper::Models::CreditRetrieveBalanceResponse
- Defined in:
- lib/x_twitter_scraper/models/credit_retrieve_balance_response.rb,
sig/x_twitter_scraper/models/credit_retrieve_balance_response.rbs
Overview
Instance Attribute Summary collapse
-
#auto_topup_amount_dollars ⇒ Float
Configured dollar amount for each automatic top-up.
- #auto_topup_enabled ⇒ Boolean
-
#auto_topup_threshold ⇒ String
Credit balance threshold that triggers automatic top-up when enabled, represented as a bigint string.
-
#balance ⇒ String
Current credit balance as a bigint string to preserve precision above Number.MAX_SAFE_INTEGER.
-
#lifetime_purchased ⇒ String
Lifetime purchased credits as a bigint string.
-
#lifetime_used ⇒ String
Lifetime consumed credits as a bigint string.
Instance Method Summary collapse
-
#initialize(auto_topup_amount_dollars:, auto_topup_enabled:, auto_topup_threshold:, balance:, lifetime_purchased:, lifetime_used:) ⇒ Object
constructor
Some parameter documentations has been truncated, see CreditRetrieveBalanceResponse for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(auto_topup_amount_dollars:, auto_topup_enabled:, auto_topup_threshold:, balance:, lifetime_purchased:, lifetime_used:) ⇒ Object
Some parameter documentations has been truncated, see XTwitterScraper::Models::CreditRetrieveBalanceResponse for more details.
|
|
# File 'lib/x_twitter_scraper/models/credit_retrieve_balance_response.rb', line 44
|
Instance Attribute Details
#auto_topup_amount_dollars ⇒ Float
Configured dollar amount for each automatic top-up.
11 |
# File 'lib/x_twitter_scraper/models/credit_retrieve_balance_response.rb', line 11 required :auto_topup_amount_dollars, Float |
#auto_topup_enabled ⇒ Boolean
16 |
# File 'lib/x_twitter_scraper/models/credit_retrieve_balance_response.rb', line 16 required :auto_topup_enabled, XTwitterScraper::Internal::Type::Boolean |
#auto_topup_threshold ⇒ String
Credit balance threshold that triggers automatic top-up when enabled, represented as a bigint string.
23 |
# File 'lib/x_twitter_scraper/models/credit_retrieve_balance_response.rb', line 23 required :auto_topup_threshold, String |
#balance ⇒ String
Current credit balance as a bigint string to preserve precision above Number.MAX_SAFE_INTEGER.
30 |
# File 'lib/x_twitter_scraper/models/credit_retrieve_balance_response.rb', line 30 required :balance, String |
#lifetime_purchased ⇒ String
Lifetime purchased credits as a bigint string.
36 |
# File 'lib/x_twitter_scraper/models/credit_retrieve_balance_response.rb', line 36 required :lifetime_purchased, String |
#lifetime_used ⇒ String
Lifetime consumed credits as a bigint string.
42 |
# File 'lib/x_twitter_scraper/models/credit_retrieve_balance_response.rb', line 42 required :lifetime_used, String |
Instance Method Details
#to_hash ⇒ {
35 |
# File 'sig/x_twitter_scraper/models/credit_retrieve_balance_response.rbs', line 35
def to_hash: -> {
|