Class: XTwitterScraper::Models::DrawDetail
Instance Attribute Summary collapse
Instance Method Summary
collapse
-
#initialize(id:, created_at:, status:, total_entries:, tweet_author_username:, tweet_id:, tweet_like_count:, tweet_quote_count:, tweet_reply_count:, tweet_retweet_count:, tweet_text:, tweet_url:, valid_entries:, drawn_at: nil) ⇒ Object
constructor
Full giveaway draw with tweet metrics, entries, and timing.
-
#to_hash ⇒ {
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, created_at:, status:, total_entries:, tweet_author_username:, tweet_id:, tweet_like_count:, tweet_quote_count:, tweet_reply_count:, tweet_retweet_count:, tweet_text:, tweet_url:, valid_entries:, drawn_at: nil) ⇒ Object
Full giveaway draw with tweet metrics, entries, and timing.
|
# File 'lib/x_twitter_scraper/models/draw_detail.rb', line 77
|
Instance Attribute Details
#created_at ⇒ Time
15
|
# File 'lib/x_twitter_scraper/models/draw_detail.rb', line 15
required :created_at, Time, api_name: :createdAt
|
#drawn_at ⇒ Time?
75
|
# File 'lib/x_twitter_scraper/models/draw_detail.rb', line 75
optional :drawn_at, Time, api_name: :drawnAt
|
#id ⇒ String
10
|
# File 'lib/x_twitter_scraper/models/draw_detail.rb', line 10
required :id, String
|
#status ⇒ String
20
|
# File 'lib/x_twitter_scraper/models/draw_detail.rb', line 20
required :status, String
|
#total_entries ⇒ Integer
25
|
# File 'lib/x_twitter_scraper/models/draw_detail.rb', line 25
required :total_entries, Integer, api_name: :totalEntries
|
30
|
# File 'lib/x_twitter_scraper/models/draw_detail.rb', line 30
required :tweet_author_username, String, api_name: :tweetAuthorUsername
|
35
|
# File 'lib/x_twitter_scraper/models/draw_detail.rb', line 35
required :tweet_id, String, api_name: :tweetId
|
40
|
# File 'lib/x_twitter_scraper/models/draw_detail.rb', line 40
required :tweet_like_count, Integer, api_name: :tweetLikeCount
|
45
|
# File 'lib/x_twitter_scraper/models/draw_detail.rb', line 45
required :tweet_quote_count, Integer, api_name: :tweetQuoteCount
|
50
|
# File 'lib/x_twitter_scraper/models/draw_detail.rb', line 50
required :tweet_reply_count, Integer, api_name: :tweetReplyCount
|
55
|
# File 'lib/x_twitter_scraper/models/draw_detail.rb', line 55
required :tweet_retweet_count, Integer, api_name: :tweetRetweetCount
|
60
|
# File 'lib/x_twitter_scraper/models/draw_detail.rb', line 60
required :tweet_text, String, api_name: :tweetText
|
65
|
# File 'lib/x_twitter_scraper/models/draw_detail.rb', line 65
required :tweet_url, String, api_name: :tweetUrl
|
#valid_entries ⇒ Integer
70
|
# File 'lib/x_twitter_scraper/models/draw_detail.rb', line 70
required :valid_entries, Integer, api_name: :validEntries
|
Instance Method Details
#to_hash ⇒ {
69
|
# File 'sig/x_twitter_scraper/models/draw_detail.rbs', line 69
def to_hash: -> {
|