Class: XTwitterScraper::Models::DrawRunResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- XTwitterScraper::Models::DrawRunResponse
- Defined in:
- lib/x_twitter_scraper/models/draw_run_response.rb,
sig/x_twitter_scraper/models/draw_run_response.rbs
Overview
Instance Attribute Summary collapse
- #id ⇒ String
-
#total_entries ⇒ Integer
Candidate entries inspected for this draw after the credit-derived cap.
- #tweet_id ⇒ String
-
#valid_entries ⇒ Integer
Entries from the inspected candidate set that passed all filters.
- #winners ⇒ Array<XTwitterScraper::Models::Winner>
Instance Method Summary collapse
-
#initialize(id:, total_entries:, tweet_id:, valid_entries:, winners:) ⇒ Object
constructor
Some parameter documentations has been truncated, see DrawRunResponse for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, total_entries:, tweet_id:, valid_entries:, winners:) ⇒ Object
Some parameter documentations has been truncated, see XTwitterScraper::Models::DrawRunResponse for more details.
|
|
# File 'lib/x_twitter_scraper/models/draw_run_response.rb', line 36
|
Instance Attribute Details
#id ⇒ String
10 |
# File 'lib/x_twitter_scraper/models/draw_run_response.rb', line 10 required :id, String |
#total_entries ⇒ Integer
Candidate entries inspected for this draw after the credit-derived cap. This may be lower than the source tweet's full reply count.
17 |
# File 'lib/x_twitter_scraper/models/draw_run_response.rb', line 17 required :total_entries, Integer, api_name: :totalEntries |
#tweet_id ⇒ String
22 |
# File 'lib/x_twitter_scraper/models/draw_run_response.rb', line 22 required :tweet_id, String, api_name: :tweetId |
#valid_entries ⇒ Integer
Entries from the inspected candidate set that passed all filters. This is not necessarily every valid reply on the source tweet when credits cap inspection.
29 |
# File 'lib/x_twitter_scraper/models/draw_run_response.rb', line 29 required :valid_entries, Integer, api_name: :validEntries |
#winners ⇒ Array<XTwitterScraper::Models::Winner>
34 |
# File 'lib/x_twitter_scraper/models/draw_run_response.rb', line 34 required :winners, -> { XTwitterScraper::Internal::Type::ArrayOf[XTwitterScraper::Winner] } |
Instance Method Details
#to_hash ⇒ {
31 |
# File 'sig/x_twitter_scraper/models/draw_run_response.rbs', line 31
def to_hash: -> {
|