Class: XTwitterScraper::Models::ExtractionRunParams::RelationTarget
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- XTwitterScraper::Models::ExtractionRunParams::RelationTarget
- Defined in:
- lib/x_twitter_scraper/models/extraction_run_params.rb,
sig/x_twitter_scraper/models/extraction_run_params.rbs
Defined Under Namespace
Modules: Relation
Instance Attribute Summary collapse
- #relation ⇒ Symbol, XTwitterScraper::Models::ExtractionRunParams::RelationTarget::Relation
- #value ⇒ String
Instance Method Summary collapse
-
#initialize(relation:, value:) ⇒ Object
constructor
One target and relation in a mixed profile collection.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(relation:, value:) ⇒ Object
One target and relation in a mixed profile collection.
|
|
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 933
|
Instance Attribute Details
#relation ⇒ Symbol, XTwitterScraper::Models::ExtractionRunParams::RelationTarget::Relation
926 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 926 required :relation, enum: -> { XTwitterScraper::ExtractionRunParams::RelationTarget::Relation } |
#value ⇒ String
931 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 931 required :value, String |
Instance Method Details
#to_hash ⇒ {
863 |
# File 'sig/x_twitter_scraper/models/extraction_run_params.rbs', line 863
def to_hash: -> {
|