Class: XTwitterScraper::Models::ExtractionRunResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- XTwitterScraper::Models::ExtractionRunResponse
- Defined in:
- lib/x_twitter_scraper/models/extraction_run_response.rb
Overview
Defined Under Namespace
Modules: ToolType
Instance Attribute Summary collapse
- #id ⇒ String
- #status ⇒ Symbol, :running
-
#tool_type ⇒ Symbol, XTwitterScraper::Models::ExtractionRunResponse::ToolType
Identifier for the extraction tool used to run a job.
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, tool_type:, status: :running) ⇒ Object
|
|
# File 'lib/x_twitter_scraper/models/extraction_run_response.rb', line 25
|
Instance Attribute Details
#id ⇒ String
10 |
# File 'lib/x_twitter_scraper/models/extraction_run_response.rb', line 10 required :id, String |
#status ⇒ Symbol, :running
15 |
# File 'lib/x_twitter_scraper/models/extraction_run_response.rb', line 15 required :status, const: :running |
#tool_type ⇒ Symbol, XTwitterScraper::Models::ExtractionRunResponse::ToolType
Identifier for the extraction tool used to run a job.
21 22 23 |
# File 'lib/x_twitter_scraper/models/extraction_run_response.rb', line 21 required :tool_type, enum: -> { XTwitterScraper::Models::ExtractionRunResponse::ToolType }, api_name: :toolType |