Class: XTwitterScraper::Models::GuestWalletRetrieveStatusResponse::TopUp
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- XTwitterScraper::Models::GuestWalletRetrieveStatusResponse::TopUp
- Defined in:
- lib/x_twitter_scraper/models/guest_wallet_retrieve_status_response.rb,
sig/x_twitter_scraper/models/guest_wallet_retrieve_status_response.rbs
Overview
Instance Attribute Summary collapse
Instance Method Summary collapse
-
#initialize(method_: :POST, path: :"/api/v1/guest-wallets/topups") ⇒ Object
constructor
Top-up action when usable and no checkout is pending.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(method_: :POST, path: :"/api/v1/guest-wallets/topups") ⇒ Object
Top-up action when usable and no checkout is pending.
|
|
# File 'lib/x_twitter_scraper/models/guest_wallet_retrieve_status_response.rb', line 188
|
Instance Attribute Details
#method_ ⇒ Symbol, :POST
181 |
# File 'lib/x_twitter_scraper/models/guest_wallet_retrieve_status_response.rb', line 181 required :method_, const: :POST, api_name: :method |
#path ⇒ Symbol, :"/api/v1/guest-wallets/topups"
186 |
# File 'lib/x_twitter_scraper/models/guest_wallet_retrieve_status_response.rb', line 186 required :path, const: :"/api/v1/guest-wallets/topups" |
Instance Method Details
#to_hash ⇒ {
156 |
# File 'sig/x_twitter_scraper/models/guest_wallet_retrieve_status_response.rbs', line 156
def to_hash: -> {
|