Class: XTwitterScraper::Models::StyleProfileSummary
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- XTwitterScraper::Models::StyleProfileSummary
- Defined in:
- lib/x_twitter_scraper/models/style_profile_summary.rb
Instance Attribute Summary collapse
Instance Method Summary collapse
-
#initialize(fetched_at:, is_own_account:, tweet_count:, x_username:) ⇒ Object
constructor
Style profile summary with tweet count and ownership flag.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(fetched_at:, is_own_account:, tweet_count:, x_username:) ⇒ Object
Style profile summary with tweet count and ownership flag.
|
|
# File 'lib/x_twitter_scraper/models/style_profile_summary.rb', line 26
|
Instance Attribute Details
#fetched_at ⇒ Time
9 |
# File 'lib/x_twitter_scraper/models/style_profile_summary.rb', line 9 required :fetched_at, Time, api_name: :fetchedAt |
#is_own_account ⇒ Boolean
14 |
# File 'lib/x_twitter_scraper/models/style_profile_summary.rb', line 14 required :is_own_account, XTwitterScraper::Internal::Type::Boolean, api_name: :isOwnAccount |
#tweet_count ⇒ Integer
19 |
# File 'lib/x_twitter_scraper/models/style_profile_summary.rb', line 19 required :tweet_count, Integer, api_name: :tweetCount |
#x_username ⇒ String
24 |
# File 'lib/x_twitter_scraper/models/style_profile_summary.rb', line 24 required :x_username, String, api_name: :xUsername |