Class: XTwitterScraper::Models::UserProfile
Instance Attribute Summary collapse
Instance Method Summary
collapse
-
#initialize(id:, name:, username:, automated_by: nil, can_dm: nil, community_role: nil, cover_picture: nil, created_at: nil, description: nil, favourites_count: nil, followers: nil, following: nil, has_custom_timelines: nil, is_automated: nil, is_blue_verified: nil, is_translator: nil, is_verified: nil, location: nil, media_count: nil, pinned_tweet_ids: nil, possibly_sensitive: nil, profile_bio: nil, profile_banner_url: nil, profile_picture: nil, protected: nil, statuses_count: nil, unavailable: nil, unavailable_reason: nil, url: nil, verified: nil, verified_type: nil, viewer_followed_by: nil, viewer_following: nil, withheld_in_countries: nil) ⇒ Object
constructor
X user profile with bio, follower counts, and verification status.
-
#to_hash ⇒ {
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, name:, username:, automated_by: nil, can_dm: nil, community_role: nil, cover_picture: nil, created_at: nil, description: nil, favourites_count: nil, followers: nil, following: nil, has_custom_timelines: nil, is_automated: nil, is_blue_verified: nil, is_translator: nil, is_verified: nil, location: nil, media_count: nil, pinned_tweet_ids: nil, possibly_sensitive: nil, profile_bio: nil, profile_banner_url: nil, profile_picture: nil, protected: nil, statuses_count: nil, unavailable: nil, unavailable_reason: nil, url: nil, verified: nil, verified_type: nil, viewer_followed_by: nil, viewer_following: nil, withheld_in_countries: nil) ⇒ Object
X user profile with bio, follower counts, and verification status.
|
# File 'lib/x_twitter_scraper/models/user_profile.rb', line 190
|
Instance Attribute Details
#automated_by ⇒ String?
28
|
# File 'lib/x_twitter_scraper/models/user_profile.rb', line 28
optional :automated_by, String, api_name: :automatedBy
|
#can_dm ⇒ Boolean?
33
|
# File 'lib/x_twitter_scraper/models/user_profile.rb', line 33
optional :can_dm, XTwitterScraper::Internal::Type::Boolean, api_name: :canDm
|
Community role when returned by community member reads
39
|
# File 'lib/x_twitter_scraper/models/user_profile.rb', line 39
optional :community_role, String, api_name: :communityRole
|
#cover_picture ⇒ String?
44
|
# File 'lib/x_twitter_scraper/models/user_profile.rb', line 44
optional :cover_picture, String, api_name: :coverPicture
|
#created_at ⇒ String?
49
|
# File 'lib/x_twitter_scraper/models/user_profile.rb', line 49
optional :created_at, String, api_name: :createdAt
|
#description ⇒ String?
54
|
# File 'lib/x_twitter_scraper/models/user_profile.rb', line 54
optional :description, String
|
#favourites_count ⇒ Integer?
59
|
# File 'lib/x_twitter_scraper/models/user_profile.rb', line 59
optional :favourites_count, Integer, api_name: :favouritesCount
|
#followers ⇒ Integer?
64
|
# File 'lib/x_twitter_scraper/models/user_profile.rb', line 64
optional :followers, Integer
|
#following ⇒ Integer?
69
|
# File 'lib/x_twitter_scraper/models/user_profile.rb', line 69
optional :following, Integer
|
#has_custom_timelines ⇒ Boolean?
74
|
# File 'lib/x_twitter_scraper/models/user_profile.rb', line 74
optional :has_custom_timelines, XTwitterScraper::Internal::Type::Boolean, api_name: :hasCustomTimelines
|
#id ⇒ String
13
|
# File 'lib/x_twitter_scraper/models/user_profile.rb', line 13
required :id, String
|
#is_automated ⇒ Boolean?
79
|
# File 'lib/x_twitter_scraper/models/user_profile.rb', line 79
optional :is_automated, XTwitterScraper::Internal::Type::Boolean, api_name: :isAutomated
|
#is_blue_verified ⇒ Boolean?
Whether X shows a blue verification badge
85
|
# File 'lib/x_twitter_scraper/models/user_profile.rb', line 85
optional :is_blue_verified, XTwitterScraper::Internal::Type::Boolean, api_name: :isBlueVerified
|
#is_translator ⇒ Boolean?
90
|
# File 'lib/x_twitter_scraper/models/user_profile.rb', line 90
optional :is_translator, XTwitterScraper::Internal::Type::Boolean, api_name: :isTranslator
|
#is_verified ⇒ Boolean?
Whether X marks the profile as verified
96
|
# File 'lib/x_twitter_scraper/models/user_profile.rb', line 96
optional :is_verified, XTwitterScraper::Internal::Type::Boolean, api_name: :isVerified
|
#location ⇒ String?
101
|
# File 'lib/x_twitter_scraper/models/user_profile.rb', line 101
optional :location, String
|
106
|
# File 'lib/x_twitter_scraper/models/user_profile.rb', line 106
optional :media_count, Integer, api_name: :mediaCount
|
#name ⇒ String
18
|
# File 'lib/x_twitter_scraper/models/user_profile.rb', line 18
required :name, String
|
111
|
# File 'lib/x_twitter_scraper/models/user_profile.rb', line 111
optional :pinned_tweet_ids, XTwitterScraper::Internal::Type::ArrayOf[String], api_name: :pinnedTweetIds
|
#possibly_sensitive ⇒ Boolean?
116
|
# File 'lib/x_twitter_scraper/models/user_profile.rb', line 116
optional :possibly_sensitive, XTwitterScraper::Internal::Type::Boolean, api_name: :possiblySensitive
|
#profile_banner_url ⇒ String?
Original X profile banner field when available
128
|
# File 'lib/x_twitter_scraper/models/user_profile.rb', line 128
optional :profile_banner_url, String, api_name: :profileBannerUrl
|
#profile_bio ⇒ Hash{Symbol=>Object}?
Structured profile bio with entity annotations
122
|
# File 'lib/x_twitter_scraper/models/user_profile.rb', line 122
optional :profile_bio, XTwitterScraper::Internal::Type::HashOf[XTwitterScraper::Internal::Type::Unknown]
|
#profile_picture ⇒ String?
133
|
# File 'lib/x_twitter_scraper/models/user_profile.rb', line 133
optional :profile_picture, String, api_name: :profilePicture
|
#protected ⇒ Boolean?
Whether the profile protects its posts
139
|
# File 'lib/x_twitter_scraper/models/user_profile.rb', line 139
optional :protected, XTwitterScraper::Internal::Type::Boolean
|
#statuses_count ⇒ Integer?
144
|
# File 'lib/x_twitter_scraper/models/user_profile.rb', line 144
optional :statuses_count, Integer, api_name: :statusesCount
|
#unavailable ⇒ Boolean?
149
|
# File 'lib/x_twitter_scraper/models/user_profile.rb', line 149
optional :unavailable, XTwitterScraper::Internal::Type::Boolean
|
#unavailable_reason ⇒ String?
154
|
# File 'lib/x_twitter_scraper/models/user_profile.rb', line 154
optional :unavailable_reason, String, api_name: :unavailableReason
|
#url ⇒ String?
159
|
# File 'lib/x_twitter_scraper/models/user_profile.rb', line 159
optional :url, String
|
#username ⇒ String
23
|
# File 'lib/x_twitter_scraper/models/user_profile.rb', line 23
required :username, String
|
#verified ⇒ Boolean?
164
|
# File 'lib/x_twitter_scraper/models/user_profile.rb', line 164
optional :verified, XTwitterScraper::Internal::Type::Boolean
|
#verified_type ⇒ String?
169
|
# File 'lib/x_twitter_scraper/models/user_profile.rb', line 169
optional :verified_type, String, api_name: :verifiedType
|
#viewer_followed_by ⇒ Boolean?
Whether this profile follows the authenticated viewer
175
|
# File 'lib/x_twitter_scraper/models/user_profile.rb', line 175
optional :viewer_followed_by, XTwitterScraper::Internal::Type::Boolean, api_name: :viewerFollowedBy
|
#viewer_following ⇒ Boolean?
Whether the authenticated viewer follows this profile
181
|
# File 'lib/x_twitter_scraper/models/user_profile.rb', line 181
optional :viewer_following, XTwitterScraper::Internal::Type::Boolean, api_name: :viewerFollowing
|
#withheld_in_countries ⇒ Array<String>?
186
187
188
|
# File 'lib/x_twitter_scraper/models/user_profile.rb', line 186
optional :withheld_in_countries,
XTwitterScraper::Internal::Type::ArrayOf[String],
api_name: :withheldInCountries
|
Instance Method Details
#to_hash ⇒ {
213
|
# File 'sig/x_twitter_scraper/models/user_profile.rbs', line 213
def to_hash: -> {
|