Class: XTwitterScraper::Models::X::Communities::TweetListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- XTwitterScraper::Models::X::Communities::TweetListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/x_twitter_scraper/models/x/communities/tweet_list_params.rb,
sig/x_twitter_scraper/models/x/communities/tweet_list_params.rbs
Overview
Defined Under Namespace
Modules: QueryType
Constant Summary
Constants included from Internal::Type::RequestParameters
Internal::Type::RequestParameters::XTwitterScraper
Instance Attribute Summary collapse
-
#community_id ⇒ String
Numeric ID of the community to search.
-
#cursor ⇒ String?
Pagination cursor for community results.
-
#page_size ⇒ Integer?
Maximum items requested from this page (1-100, default 20).
-
#q ⇒ String
Keyword query within the selected community.
-
#query_type ⇒ Symbol, ...
Sort order for community results (Latest or Top).
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(community_id:, q:, cursor: nil, page_size: nil, query_type: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see TweetListParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(community_id:, q:, cursor: nil, page_size: nil, query_type: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see XTwitterScraper::Models::X::Communities::TweetListParams for more details.
|
|
# File 'lib/x_twitter_scraper/models/x/communities/tweet_list_params.rb', line 46
|
Instance Attribute Details
#community_id ⇒ String
Numeric ID of the community to search
16 |
# File 'lib/x_twitter_scraper/models/x/communities/tweet_list_params.rb', line 16 required :community_id, String |
#cursor ⇒ String?
Pagination cursor for community results
28 |
# File 'lib/x_twitter_scraper/models/x/communities/tweet_list_params.rb', line 28 optional :cursor, String |
#page_size ⇒ Integer?
Maximum items requested from this page (1-100, default 20). The response can contain fewer items because the source returned fewer, filters removed items, or remaining credits cover fewer results. Keep requesting next_cursor while has_next_page is true, even when a page is empty. The deprecated limit and count aliases remain accepted.
38 |
# File 'lib/x_twitter_scraper/models/x/communities/tweet_list_params.rb', line 38 optional :page_size, Integer |
#q ⇒ String
Keyword query within the selected community
22 |
# File 'lib/x_twitter_scraper/models/x/communities/tweet_list_params.rb', line 22 required :q, String |
#query_type ⇒ Symbol, ...
Sort order for community results (Latest or Top)
44 |
# File 'lib/x_twitter_scraper/models/x/communities/tweet_list_params.rb', line 44 optional :query_type, enum: -> { XTwitterScraper::X::Communities::TweetListParams::QueryType } |
Instance Method Details
#to_hash ⇒ {
46 |
# File 'sig/x_twitter_scraper/models/x/communities/tweet_list_params.rbs', line 46
def to_hash: -> {
|