Class: XTwitterScraper::Models::X::CommunityRetrieveSearchParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- XTwitterScraper::Models::X::CommunityRetrieveSearchParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/x_twitter_scraper/models/x/community_retrieve_search_params.rb,
sig/x_twitter_scraper/models/x/community_retrieve_search_params.rbs
Overview
Defined Under Namespace
Modules: QueryType
Constant Summary
Constants included from Internal::Type::RequestParameters
Internal::Type::RequestParameters::XTwitterScraper
Instance Attribute Summary collapse
-
#community_id ⇒ String
Numeric ID of the community whose posts to search.
-
#cursor ⇒ String?
Pagination cursor for community search.
-
#page_size ⇒ Integer?
Maximum items requested from this page (1-100, default 20).
-
#q ⇒ String
Search query.
-
#query_type ⇒ Symbol, ...
Sort order (Latest or Top).
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(community_id:, q:, cursor: nil, page_size: nil, query_type: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see CommunityRetrieveSearchParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(community_id:, q:, cursor: nil, page_size: nil, query_type: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see XTwitterScraper::Models::X::CommunityRetrieveSearchParams for more details.
|
|
# File 'lib/x_twitter_scraper/models/x/community_retrieve_search_params.rb', line 45
|
Instance Attribute Details
#community_id ⇒ String
Numeric ID of the community whose posts to search
15 |
# File 'lib/x_twitter_scraper/models/x/community_retrieve_search_params.rb', line 15 required :community_id, String |
#cursor ⇒ String?
Pagination cursor for community search
27 |
# File 'lib/x_twitter_scraper/models/x/community_retrieve_search_params.rb', line 27 optional :cursor, String |
#page_size ⇒ Integer?
Maximum items requested from this page (1-100, default 20). The response can contain fewer items because the source returned fewer, filters removed items, or remaining credits cover fewer results. Keep requesting next_cursor while has_next_page is true, even when a page is empty. The deprecated limit and count aliases remain accepted.
37 |
# File 'lib/x_twitter_scraper/models/x/community_retrieve_search_params.rb', line 37 optional :page_size, Integer |
#q ⇒ String
Search query
21 |
# File 'lib/x_twitter_scraper/models/x/community_retrieve_search_params.rb', line 21 required :q, String |
#query_type ⇒ Symbol, ...
Sort order (Latest or Top)
43 |
# File 'lib/x_twitter_scraper/models/x/community_retrieve_search_params.rb', line 43 optional :query_type, enum: -> { XTwitterScraper::X::CommunityRetrieveSearchParams::QueryType } |
Instance Method Details
#to_hash ⇒ {
45 |
# File 'sig/x_twitter_scraper/models/x/community_retrieve_search_params.rbs', line 45
def to_hash: -> {
|