Class: XTwitterScraper::Models::X::DmRetrieveHistoryParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- XTwitterScraper::Models::X::DmRetrieveHistoryParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/x_twitter_scraper/models/x/dm_retrieve_history_params.rb,
sig/x_twitter_scraper/models/x/dm_retrieve_history_params.rbs
Overview
Constant Summary
Constants included from Internal::Type::RequestParameters
Internal::Type::RequestParameters::XTwitterScraper
Instance Attribute Summary collapse
-
#account ⇒ String
X handle (without the
@prefix) of the connected X account used to read the conversation. -
#cursor ⇒ String?
Pagination cursor for DM history.
-
#max_id ⇒ String?
Legacy pagination cursor (backward compat).
- #user_id ⇒ String
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(user_id:, account:, cursor: nil, max_id: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see DmRetrieveHistoryParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(user_id:, account:, cursor: nil, max_id: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see XTwitterScraper::Models::X::DmRetrieveHistoryParams for more details.
|
|
# File 'lib/x_twitter_scraper/models/x/dm_retrieve_history_params.rb', line 35
|
Instance Attribute Details
#account ⇒ String
X handle (without the @ prefix) of the connected X account used to read the
conversation. The account must be a participant in the conversation.
21 |
# File 'lib/x_twitter_scraper/models/x/dm_retrieve_history_params.rb', line 21 required :account, String |
#cursor ⇒ String?
Pagination cursor for DM history
27 |
# File 'lib/x_twitter_scraper/models/x/dm_retrieve_history_params.rb', line 27 optional :cursor, String |
#max_id ⇒ String?
Legacy pagination cursor (backward compat)
33 |
# File 'lib/x_twitter_scraper/models/x/dm_retrieve_history_params.rb', line 33 optional :max_id, String |
#user_id ⇒ String
14 |
# File 'lib/x_twitter_scraper/models/x/dm_retrieve_history_params.rb', line 14 required :user_id, String |
Instance Method Details
#to_hash ⇒ {
32 |
# File 'sig/x_twitter_scraper/models/x/dm_retrieve_history_params.rbs', line 32
def to_hash: -> {
|