Module: XTwitterScraper::Models::X::TweetGetRepliesParams::Mode
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/x_twitter_scraper/models/x/tweet_get_replies_params.rb,
sig/x_twitter_scraper/models/x/tweet_get_replies_params.rbs
Overview
Optional advanced override. Omit mode for automatic maximum direct reply coverage with pagination. Standard keeps legacy pagination. Complete returns direct and nested replies with diagnostics, scope, depth, sorting, and original-post controls.
Constant Summary collapse
- STANDARD =
:standard- COMPLETE =
:complete
Instance Method Summary collapse
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Instance Method Details
#self?.values ⇒ ::Array[XTwitterScraper::Models::X::TweetGetRepliesParams::mode]
459 |
# File 'sig/x_twitter_scraper/models/x/tweet_get_replies_params.rbs', line 459
def self?.values: -> ::Array[XTwitterScraper::Models::X::TweetGetRepliesParams::mode]
|