Class: XTwitterScraper::Models::X::TweetRetrieveResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/x_twitter_scraper/models/x/tweet_retrieve_response.rb,
sig/x_twitter_scraper/models/x/tweet_retrieve_response.rbs

Overview

See Also:

  • XTwitterScraper::Resources::X::Tweets#retrieve

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(tweet:, author: nil) ⇒ Object

Some parameter documentations has been truncated, see XTwitterScraper::Models::X::TweetRetrieveResponse for more details.

Parameters:



# File 'lib/x_twitter_scraper/models/x/tweet_retrieve_response.rb', line 22

Instance Attribute Details

#authorXTwitterScraper::Models::X::TweetAuthor?

Tweet author profile. The lookup route always includes follower count and verification state. Other profile fields appear when available.



20
# File 'lib/x_twitter_scraper/models/x/tweet_retrieve_response.rb', line 20

optional :author, -> { XTwitterScraper::X::TweetAuthor }

#tweetXTwitterScraper::Models::X::TweetDetail

Full tweet with text, engagement metrics, media, and metadata. A zero metric can mean X did not report the count.

Parameters:

  • value (XTwitterScraper::X::TweetDetail)

Returns:



13
# File 'lib/x_twitter_scraper/models/x/tweet_retrieve_response.rb', line 13

required :tweet, -> { XTwitterScraper::X::TweetDetail }

Instance Method Details

#to_hash{

Returns:

  • ({)


24
# File 'sig/x_twitter_scraper/models/x/tweet_retrieve_response.rbs', line 24

def to_hash: -> {