Class: XTwitterScraper::Models::X::UserProfile
Overview
Instance Attribute Summary collapse
Instance Method Summary
collapse
-
#initialize(id:, name:, username:, created_at: nil, description: nil, followers: nil, following: nil, location: nil, profile_picture: nil, statuses_count: nil, verified: nil) ⇒ Object
constructor
X user profile with bio, follower counts, and verification status.
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, name:, username:, created_at: nil, description: nil, followers: nil, following: nil, location: nil, profile_picture: nil, statuses_count: nil, verified: nil) ⇒ Object
X user profile with bio, follower counts, and verification status.
|
# File 'lib/x_twitter_scraper/models/x/user_profile.rb', line 63
|
Instance Attribute Details
#created_at ⇒ String?
26
|
# File 'lib/x_twitter_scraper/models/x/user_profile.rb', line 26
optional :created_at, String, api_name: :createdAt
|
#description ⇒ String?
31
|
# File 'lib/x_twitter_scraper/models/x/user_profile.rb', line 31
optional :description, String
|
#followers ⇒ Integer?
36
|
# File 'lib/x_twitter_scraper/models/x/user_profile.rb', line 36
optional :followers, Integer
|
#following ⇒ Integer?
41
|
# File 'lib/x_twitter_scraper/models/x/user_profile.rb', line 41
optional :following, Integer
|
#id ⇒ String
11
|
# File 'lib/x_twitter_scraper/models/x/user_profile.rb', line 11
required :id, String
|
#location ⇒ String?
46
|
# File 'lib/x_twitter_scraper/models/x/user_profile.rb', line 46
optional :location, String
|
#name ⇒ String
16
|
# File 'lib/x_twitter_scraper/models/x/user_profile.rb', line 16
required :name, String
|
#profile_picture ⇒ String?
51
|
# File 'lib/x_twitter_scraper/models/x/user_profile.rb', line 51
optional :profile_picture, String, api_name: :profilePicture
|
#statuses_count ⇒ Integer?
56
|
# File 'lib/x_twitter_scraper/models/x/user_profile.rb', line 56
optional :statuses_count, Integer, api_name: :statusesCount
|
#username ⇒ String
21
|
# File 'lib/x_twitter_scraper/models/x/user_profile.rb', line 21
required :username, String
|