Class: XTwitterScraper::Models::X::UserRetrieveTweetsParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/x_twitter_scraper/models/x/user_retrieve_tweets_params.rb,
sig/x_twitter_scraper/models/x/user_retrieve_tweets_params.rbs

Overview

See Also:

  • XTwitterScraper::Resources::X::Users#retrieve_tweets

Defined Under Namespace

Modules: MediaType, Quotes, Replies, Retweets

Constant Summary

Constants included from Internal::Type::RequestParameters

Internal::Type::RequestParameters::XTwitterScraper

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, any_words: nil, blue_verified_only: nil, card_name: nil, cashtags: nil, conversation_id: nil, cursor: nil, exact_phrase: nil, exclude_source: nil, exclude_words: nil, from_user: nil, geocode: nil, hashtags: nil, include_parent_tweet: nil, include_replies: nil, in_reply_to_tweet_id: nil, language: nil, max_faves: nil, max_id: nil, max_quotes: nil, max_replies: nil, max_retweets: nil, media_type: nil, mentioning: nil, min_bookmarks: nil, min_faves: nil, min_quotes: nil, min_replies: nil, min_retweets: nil, min_views: nil, native_retweets: nil, near: nil, news: nil, page_size: nil, quotes: nil, quotes_of_tweet_id: nil, replies: nil, retweets: nil, retweets_of_tweet_id: nil, safe: nil, since_date: nil, since_id: nil, source: nil, to_user: nil, until_date: nil, url: nil, verified_only: nil, within: nil, within_time: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see XTwitterScraper::Models::X::UserRetrieveTweetsParams for more details.

Parameters:

  • id (String)
  • any_words (String) (defaults to: nil)

    Words or quoted phrases where any one can match. Separate with spaces, commas, o

  • blue_verified_only (Boolean) (defaults to: nil)

    Only return tweets from Blue-verified authors.

  • card_name (String) (defaults to: nil)

    Match the Tweet card name.

  • cashtags (String) (defaults to: nil)

    Cashtags separated by spaces, commas, or lines.

  • conversation_id (String) (defaults to: nil)

    Conversation ID filter.

  • cursor (String) (defaults to: nil)

    Cursor from the previous response. Xquik cursors resume automatic coverage. Exis

  • exact_phrase (String) (defaults to: nil)

    Exact phrase to match.

  • exclude_source (String) (defaults to: nil)

    Exclude a source application.

  • exclude_words (String) (defaults to: nil)

    Words or quoted phrases to exclude. Separate with spaces, commas, or lines.

  • from_user (String) (defaults to: nil)

    Filter by author username.

  • geocode (String) (defaults to: nil)

    Match latitude, longitude, and radius.

  • hashtags (String) (defaults to: nil)

    Hashtags separated by spaces, commas, or lines.

  • include_parent_tweet (Boolean) (defaults to: nil)

    Include parent tweet for replies

  • include_replies (Boolean) (defaults to: nil)

    Include reply tweets

  • in_reply_to_tweet_id (String) (defaults to: nil)

    Only replies to this tweet ID.

  • language (String) (defaults to: nil)

    Language code filter, e.g. en or tr.

  • max_faves (Integer) (defaults to: nil)

    Maximum likes threshold. maxLikes is also accepted.

  • max_id (String) (defaults to: nil)

    Return Tweets older than this Tweet ID.

  • max_quotes (Integer) (defaults to: nil)

    Maximum quotes threshold.

  • max_replies (Integer) (defaults to: nil)

    Maximum replies threshold.

  • max_retweets (Integer) (defaults to: nil)

    Maximum retweets threshold.

  • media_type (Symbol, XTwitterScraper::Models::X::UserRetrieveTweetsParams::MediaType) (defaults to: nil)

    Filter by media type.

  • mentioning (String) (defaults to: nil)

    Filter tweets mentioning a username.

  • min_bookmarks (Integer) (defaults to: nil)

    Minimum bookmark count threshold.

  • min_faves (Integer) (defaults to: nil)

    Minimum likes threshold. minLikes is also accepted.

  • min_quotes (Integer) (defaults to: nil)

    Minimum quote count threshold.

  • min_replies (Integer) (defaults to: nil)

    Minimum replies threshold.

  • min_retweets (Integer) (defaults to: nil)

    Minimum retweets threshold.

  • min_views (Integer) (defaults to: nil)

    Minimum view count threshold.

  • native_retweets (Boolean) (defaults to: nil)

    Only return native reposts.

  • near (String) (defaults to: nil)

    Match a place name.

  • news (Boolean) (defaults to: nil)

    Only return news results.

  • page_size (Integer) (defaults to: nil)

    Automatic pages accept 1-300 Tweets. Standard pages keep 1-100. Default 20. Cont

  • quotes (Symbol, XTwitterScraper::Models::X::UserRetrieveTweetsParams::Quotes) (defaults to: nil)

    Quote mode.

  • quotes_of_tweet_id (String) (defaults to: nil)

    Only quotes of this tweet ID.

  • replies (Symbol, XTwitterScraper::Models::X::UserRetrieveTweetsParams::Replies) (defaults to: nil)

    Reply mode.

  • retweets (Symbol, XTwitterScraper::Models::X::UserRetrieveTweetsParams::Retweets) (defaults to: nil)

    Retweet mode.

  • retweets_of_tweet_id (String) (defaults to: nil)

    Only retweets of this tweet ID.

  • safe (Boolean) (defaults to: nil)

    Enable the safe-search filter.

  • since_date (Date) (defaults to: nil)

    Start date in YYYY-MM-DD format.

  • since_id (String) (defaults to: nil)

    Return Tweets newer than this Tweet ID.

  • source (String) (defaults to: nil)

    Match the source application.

  • to_user (String) (defaults to: nil)

    Filter replies sent to a username.

  • until_date (Date) (defaults to: nil)

    End date in YYYY-MM-DD format.

  • url (String) (defaults to: nil)

    URL substring or domain filter.

  • verified_only (Boolean) (defaults to: nil)

    Only return tweets from verified authors.

  • within (String) (defaults to: nil)

    Set the radius for the near filter.

  • within_time (String) (defaults to: nil)

    Match Tweets inside a recent time window.

  • request_options (XTwitterScraper::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/x_twitter_scraper/models/x/user_retrieve_tweets_params.rb', line 311

Instance Attribute Details

#any_wordsString?

Words or quoted phrases where any one can match. Separate with spaces, commas, or lines.

Parameters:

  • (String)

Returns:

  • (String, nil)


25
# File 'lib/x_twitter_scraper/models/x/user_retrieve_tweets_params.rb', line 25

optional :any_words, String

#blue_verified_onlyBoolean?

Only return tweets from Blue-verified authors.

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


31
# File 'lib/x_twitter_scraper/models/x/user_retrieve_tweets_params.rb', line 31

optional :blue_verified_only, XTwitterScraper::Internal::Type::Boolean

#card_nameString?

Match the Tweet card name.

Parameters:

  • (String)

Returns:

  • (String, nil)


37
# File 'lib/x_twitter_scraper/models/x/user_retrieve_tweets_params.rb', line 37

optional :card_name, String

#cashtagsString?

Cashtags separated by spaces, commas, or lines.

Parameters:

  • (String)

Returns:

  • (String, nil)


43
# File 'lib/x_twitter_scraper/models/x/user_retrieve_tweets_params.rb', line 43

optional :cashtags, String

#conversation_idString?

Conversation ID filter.

Parameters:

  • (String)

Returns:

  • (String, nil)


49
# File 'lib/x_twitter_scraper/models/x/user_retrieve_tweets_params.rb', line 49

optional :conversation_id, String

#cursorString?

Cursor from the previous response. Xquik cursors resume automatic coverage. Existing unprefixed cursors keep legacy standard behavior.

Parameters:

  • (String)

Returns:

  • (String, nil)


56
# File 'lib/x_twitter_scraper/models/x/user_retrieve_tweets_params.rb', line 56

optional :cursor, String

#exact_phraseString?

Exact phrase to match.

Parameters:

  • (String)

Returns:

  • (String, nil)


62
# File 'lib/x_twitter_scraper/models/x/user_retrieve_tweets_params.rb', line 62

optional :exact_phrase, String

#exclude_sourceString?

Exclude a source application.

Parameters:

  • (String)

Returns:

  • (String, nil)


68
# File 'lib/x_twitter_scraper/models/x/user_retrieve_tweets_params.rb', line 68

optional :exclude_source, String

#exclude_wordsString?

Words or quoted phrases to exclude. Separate with spaces, commas, or lines.

Parameters:

  • (String)

Returns:

  • (String, nil)


74
# File 'lib/x_twitter_scraper/models/x/user_retrieve_tweets_params.rb', line 74

optional :exclude_words, String

#from_userString?

Filter by author username.

Parameters:

  • (String)

Returns:

  • (String, nil)


80
# File 'lib/x_twitter_scraper/models/x/user_retrieve_tweets_params.rb', line 80

optional :from_user, String

#geocodeString?

Match latitude, longitude, and radius.

Parameters:

  • (String)

Returns:

  • (String, nil)


86
# File 'lib/x_twitter_scraper/models/x/user_retrieve_tweets_params.rb', line 86

optional :geocode, String

#hashtagsString?

Hashtags separated by spaces, commas, or lines.

Parameters:

  • (String)

Returns:

  • (String, nil)


92
# File 'lib/x_twitter_scraper/models/x/user_retrieve_tweets_params.rb', line 92

optional :hashtags, String

#idString

Parameters:

  • value (String)

Returns:

  • (String)


18
# File 'lib/x_twitter_scraper/models/x/user_retrieve_tweets_params.rb', line 18

required :id, String

#in_reply_to_tweet_idString?

Only replies to this tweet ID.

Parameters:

  • (String)

Returns:

  • (String, nil)


110
# File 'lib/x_twitter_scraper/models/x/user_retrieve_tweets_params.rb', line 110

optional :in_reply_to_tweet_id, String

#include_parent_tweetBoolean?

Include parent tweet for replies

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


98
# File 'lib/x_twitter_scraper/models/x/user_retrieve_tweets_params.rb', line 98

optional :include_parent_tweet, XTwitterScraper::Internal::Type::Boolean

#include_repliesBoolean?

Include reply tweets

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


104
# File 'lib/x_twitter_scraper/models/x/user_retrieve_tweets_params.rb', line 104

optional :include_replies, XTwitterScraper::Internal::Type::Boolean

#languageString?

Language code filter, e.g. en or tr.

Parameters:

  • (String)

Returns:

  • (String, nil)


116
# File 'lib/x_twitter_scraper/models/x/user_retrieve_tweets_params.rb', line 116

optional :language, String

#max_favesInteger?

Maximum likes threshold. maxLikes is also accepted.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


122
# File 'lib/x_twitter_scraper/models/x/user_retrieve_tweets_params.rb', line 122

optional :max_faves, Integer

#max_idString?

Return Tweets older than this Tweet ID.

Parameters:

  • (String)

Returns:

  • (String, nil)


128
# File 'lib/x_twitter_scraper/models/x/user_retrieve_tweets_params.rb', line 128

optional :max_id, String

#max_quotesInteger?

Maximum quotes threshold.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


134
# File 'lib/x_twitter_scraper/models/x/user_retrieve_tweets_params.rb', line 134

optional :max_quotes, Integer

#max_repliesInteger?

Maximum replies threshold.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


140
# File 'lib/x_twitter_scraper/models/x/user_retrieve_tweets_params.rb', line 140

optional :max_replies, Integer

#max_retweetsInteger?

Maximum retweets threshold.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


146
# File 'lib/x_twitter_scraper/models/x/user_retrieve_tweets_params.rb', line 146

optional :max_retweets, Integer

#media_typeSymbol, ...

Filter by media type.



152
# File 'lib/x_twitter_scraper/models/x/user_retrieve_tweets_params.rb', line 152

optional :media_type, enum: -> { XTwitterScraper::X::UserRetrieveTweetsParams::MediaType }

#mentioningString?

Filter tweets mentioning a username.

Parameters:

  • (String)

Returns:

  • (String, nil)


158
# File 'lib/x_twitter_scraper/models/x/user_retrieve_tweets_params.rb', line 158

optional :mentioning, String

#min_bookmarksInteger?

Minimum bookmark count threshold.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


164
# File 'lib/x_twitter_scraper/models/x/user_retrieve_tweets_params.rb', line 164

optional :min_bookmarks, Integer

#min_favesInteger?

Minimum likes threshold. minLikes is also accepted.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


170
# File 'lib/x_twitter_scraper/models/x/user_retrieve_tweets_params.rb', line 170

optional :min_faves, Integer

#min_quotesInteger?

Minimum quote count threshold.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


176
# File 'lib/x_twitter_scraper/models/x/user_retrieve_tweets_params.rb', line 176

optional :min_quotes, Integer

#min_repliesInteger?

Minimum replies threshold.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


182
# File 'lib/x_twitter_scraper/models/x/user_retrieve_tweets_params.rb', line 182

optional :min_replies, Integer

#min_retweetsInteger?

Minimum retweets threshold.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


188
# File 'lib/x_twitter_scraper/models/x/user_retrieve_tweets_params.rb', line 188

optional :min_retweets, Integer

#min_viewsInteger?

Minimum view count threshold.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


194
# File 'lib/x_twitter_scraper/models/x/user_retrieve_tweets_params.rb', line 194

optional :min_views, Integer

#native_retweetsBoolean?

Only return native reposts.

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


200
# File 'lib/x_twitter_scraper/models/x/user_retrieve_tweets_params.rb', line 200

optional :native_retweets, XTwitterScraper::Internal::Type::Boolean

#nearString?

Match a place name.

Parameters:

  • (String)

Returns:

  • (String, nil)


206
# File 'lib/x_twitter_scraper/models/x/user_retrieve_tweets_params.rb', line 206

optional :near, String

#newsBoolean?

Only return news results.

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


212
# File 'lib/x_twitter_scraper/models/x/user_retrieve_tweets_params.rb', line 212

optional :news, XTwitterScraper::Internal::Type::Boolean

#page_sizeInteger?

Automatic pages accept 1-300 Tweets. Standard pages keep 1-100. Default 20. Continue while has_next_page is true. Deprecated aliases remain accepted.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


219
# File 'lib/x_twitter_scraper/models/x/user_retrieve_tweets_params.rb', line 219

optional :page_size, Integer

#quotesSymbol, ...

Quote mode.



225
# File 'lib/x_twitter_scraper/models/x/user_retrieve_tweets_params.rb', line 225

optional :quotes, enum: -> { XTwitterScraper::X::UserRetrieveTweetsParams::Quotes }

#quotes_of_tweet_idString?

Only quotes of this tweet ID.

Parameters:

  • (String)

Returns:

  • (String, nil)


231
# File 'lib/x_twitter_scraper/models/x/user_retrieve_tweets_params.rb', line 231

optional :quotes_of_tweet_id, String

#repliesSymbol, ...

Reply mode.



237
# File 'lib/x_twitter_scraper/models/x/user_retrieve_tweets_params.rb', line 237

optional :replies, enum: -> { XTwitterScraper::X::UserRetrieveTweetsParams::Replies }

#retweetsSymbol, ...

Retweet mode.



243
# File 'lib/x_twitter_scraper/models/x/user_retrieve_tweets_params.rb', line 243

optional :retweets, enum: -> { XTwitterScraper::X::UserRetrieveTweetsParams::Retweets }

#retweets_of_tweet_idString?

Only retweets of this tweet ID.

Parameters:

  • (String)

Returns:

  • (String, nil)


249
# File 'lib/x_twitter_scraper/models/x/user_retrieve_tweets_params.rb', line 249

optional :retweets_of_tweet_id, String

#safeBoolean?

Enable the safe-search filter.

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


255
# File 'lib/x_twitter_scraper/models/x/user_retrieve_tweets_params.rb', line 255

optional :safe, XTwitterScraper::Internal::Type::Boolean

#since_dateDate?

Start date in YYYY-MM-DD format.

Parameters:

  • (Date)

Returns:

  • (Date, nil)


261
# File 'lib/x_twitter_scraper/models/x/user_retrieve_tweets_params.rb', line 261

optional :since_date, Date

#since_idString?

Return Tweets newer than this Tweet ID.

Parameters:

  • (String)

Returns:

  • (String, nil)


267
# File 'lib/x_twitter_scraper/models/x/user_retrieve_tweets_params.rb', line 267

optional :since_id, String

#sourceString?

Match the source application.

Parameters:

  • (String)

Returns:

  • (String, nil)


273
# File 'lib/x_twitter_scraper/models/x/user_retrieve_tweets_params.rb', line 273

optional :source, String

#to_userString?

Filter replies sent to a username.

Parameters:

  • (String)

Returns:

  • (String, nil)


279
# File 'lib/x_twitter_scraper/models/x/user_retrieve_tweets_params.rb', line 279

optional :to_user, String

#until_dateDate?

End date in YYYY-MM-DD format.

Parameters:

  • (Date)

Returns:

  • (Date, nil)


285
# File 'lib/x_twitter_scraper/models/x/user_retrieve_tweets_params.rb', line 285

optional :until_date, Date

#urlString?

URL substring or domain filter.

Parameters:

  • (String)

Returns:

  • (String, nil)


291
# File 'lib/x_twitter_scraper/models/x/user_retrieve_tweets_params.rb', line 291

optional :url, String

#verified_onlyBoolean?

Only return tweets from verified authors.

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


297
# File 'lib/x_twitter_scraper/models/x/user_retrieve_tweets_params.rb', line 297

optional :verified_only, XTwitterScraper::Internal::Type::Boolean

#withinString?

Set the radius for the near filter.

Parameters:

  • (String)

Returns:

  • (String, nil)


303
# File 'lib/x_twitter_scraper/models/x/user_retrieve_tweets_params.rb', line 303

optional :within, String

#within_timeString?

Match Tweets inside a recent time window.

Parameters:

  • (String)

Returns:

  • (String, nil)


309
# File 'lib/x_twitter_scraper/models/x/user_retrieve_tweets_params.rb', line 309

optional :within_time, String

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/x_twitter_scraper/models/x/user_retrieve_tweets_params.rb', line 426

Instance Method Details

#to_hash{

Returns:

  • ({)


321
# File 'sig/x_twitter_scraper/models/x/user_retrieve_tweets_params.rbs', line 321

def to_hash: -> {