Class: XTwitterScraper::Models::ExtractionEstimateCostParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/x_twitter_scraper/models/extraction_estimate_cost_params.rb,
sig/x_twitter_scraper/models/extraction_estimate_cost_params.rbs

Overview

See Also:

  • XTwitterScraper::Resources::Extractions#estimate_cost

Defined Under Namespace

Modules: MediaType, Quotes, Replies, Retweets, ToolType

Constant Summary

Constants included from Internal::Type::RequestParameters

Internal::Type::RequestParameters::XTwitterScraper

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(tool_type:, advanced_query: nil, any_words: nil, bounding_box: nil, cashtags: nil, conversation_id: nil, exact_phrase: nil, exclude_words: nil, from_user: nil, hashtags: nil, in_reply_to_tweet_id: nil, language: nil, list_id: nil, media_type: nil, mentioning: nil, min_faves: nil, min_quotes: nil, min_replies: nil, min_retweets: nil, place: nil, place_country: nil, point_radius: nil, quotes: nil, quotes_of_tweet_id: nil, replies: nil, results_limit: nil, retweets: nil, retweets_of_tweet_id: nil, search_query: nil, since_date: nil, target_community_id: nil, target_list_id: nil, target_space_id: nil, target_tweet_id: nil, target_username: nil, to_user: nil, until_date: nil, url: nil, verified_only: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see XTwitterScraper::Models::ExtractionEstimateCostParams for more details.

Parameters:

  • tool_type (Symbol, XTwitterScraper::Models::ExtractionEstimateCostParams::ToolType)

    Identifier for the extraction tool used to run a job.

  • advanced_query (String) (defaults to: nil)

    Raw advanced query string appended to the estimate (tweet_search_extractor)

  • any_words (String) (defaults to: nil)

    Alternative words or quoted phrases for estimated results. Separate with spaces,

  • bounding_box (String) (defaults to: nil)

    Geo bounding box used for estimation, e.g. -74.1 40.6 -73.9 40.8 (tweet_search_e

  • cashtags (String) (defaults to: nil)

    Cashtags applied to the estimate, separated by spaces, commas, or lines.

  • conversation_id (String) (defaults to: nil)

    Conversation ID filter used for estimation (tweet_search_extractor)

  • exact_phrase (String) (defaults to: nil)

    Exact phrase filter for search estimation

  • exclude_words (String) (defaults to: nil)

    Words or quoted phrases excluded from estimated results. Separate with spaces, c

  • from_user (String) (defaults to: nil)

    Estimate only tweets from this author username (tweet_search_extractor)

  • hashtags (String) (defaults to: nil)

    Hashtags applied to the estimate, separated by spaces, commas, or lines.

  • in_reply_to_tweet_id (String) (defaults to: nil)

    Estimate only replies to this tweet ID (tweet_search_extractor)

  • language (String) (defaults to: nil)

    Language code used for estimate filtering (tweet_search_extractor)

  • list_id (String) (defaults to: nil)

    Estimate search results within this list ID (tweet_search_extractor)

  • media_type (Symbol, XTwitterScraper::Models::ExtractionEstimateCostParams::MediaType) (defaults to: nil)

    Media type used for estimate filtering (tweet_search_extractor)

  • mentioning (String) (defaults to: nil)

    Estimate tweets mentioning this username (tweet_search_extractor)

  • min_faves (Integer) (defaults to: nil)

    Minimum likes threshold for estimated results (tweet_search_extractor)

  • min_quotes (Integer) (defaults to: nil)

    Minimum quote count threshold for estimated results (tweet_search_extractor)

  • min_replies (Integer) (defaults to: nil)

    Minimum replies threshold for estimated results (tweet_search_extractor)

  • min_retweets (Integer) (defaults to: nil)

    Minimum retweets threshold for estimated results (tweet_search_extractor)

  • place (String) (defaults to: nil)

    Estimate search results within this place ID (tweet_search_extractor)

  • place_country (String) (defaults to: nil)

    Estimate search results within this country code (tweet_search_extractor)

  • point_radius (String) (defaults to: nil)

    Geo point radius used for estimation, e.g. -73.99 40.73 25mi (tweet_search_extra

  • quotes (Symbol, XTwitterScraper::Models::ExtractionEstimateCostParams::Quotes) (defaults to: nil)

    Quote mode used for estimation (tweet_search_extractor)

  • quotes_of_tweet_id (String) (defaults to: nil)

    Estimate only quotes of this tweet ID (tweet_search_extractor)

  • replies (Symbol, XTwitterScraper::Models::ExtractionEstimateCostParams::Replies) (defaults to: nil)

    Reply mode used for estimation (tweet_search_extractor)

  • results_limit (Integer) (defaults to: nil)

    Maximum number of results to estimate. When set, the estimate caps projected res

  • retweets (Symbol, XTwitterScraper::Models::ExtractionEstimateCostParams::Retweets) (defaults to: nil)

    Retweet mode used for estimation (tweet_search_extractor)

  • retweets_of_tweet_id (String) (defaults to: nil)

    Estimate only retweets of this tweet ID (tweet_search_extractor)

  • search_query (String) (defaults to: nil)

    Required for tweet_search_extractor & community_search.

  • since_date (Date) (defaults to: nil)

    Estimate start date in YYYY-MM-DD format (tweet_search_extractor)

  • target_community_id (String) (defaults to: nil)

    Required for community_post_extractor & community_search.

  • target_list_id (String) (defaults to: nil)

    Required for list_follower_explorer, list_member_extractor & list_post_extractor

  • target_space_id (String) (defaults to: nil)

    Required for space_explorer.

  • target_tweet_id (String) (defaults to: nil)
  • target_username (String) (defaults to: nil)
  • to_user (String) (defaults to: nil)

    Estimate replies sent to this username (tweet_search_extractor)

  • until_date (Date) (defaults to: nil)

    Estimate end date in YYYY-MM-DD format (tweet_search_extractor)

  • url (String) (defaults to: nil)

    URL substring or domain filter used for estimation (tweet_search_extractor)

  • verified_only (Boolean) (defaults to: nil)

    Estimate only verified authors (tweet_search_extractor)

  • request_options (XTwitterScraper::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/x_twitter_scraper/models/extraction_estimate_cost_params.rb', line 252

Instance Attribute Details

#advanced_queryString?

Raw advanced query string appended to the estimate (tweet_search_extractor)

Parameters:

  • (String)

Returns:

  • (String, nil)


22
# File 'lib/x_twitter_scraper/models/extraction_estimate_cost_params.rb', line 22

optional :advanced_query, String, api_name: :advancedQuery

#any_wordsString?

Alternative words or quoted phrases for estimated results. Separate with spaces, commas, or lines.

Parameters:

  • (String)

Returns:

  • (String, nil)


29
# File 'lib/x_twitter_scraper/models/extraction_estimate_cost_params.rb', line 29

optional :any_words, String, api_name: :anyWords

#bounding_boxString?

Geo bounding box used for estimation, e.g. -74.1 40.6 -73.9 40.8 (tweet_search_extractor)

Parameters:

  • (String)

Returns:

  • (String, nil)


36
# File 'lib/x_twitter_scraper/models/extraction_estimate_cost_params.rb', line 36

optional :bounding_box, String, api_name: :boundingBox

#cashtagsString?

Cashtags applied to the estimate, separated by spaces, commas, or lines.

Parameters:

  • (String)

Returns:

  • (String, nil)


42
# File 'lib/x_twitter_scraper/models/extraction_estimate_cost_params.rb', line 42

optional :cashtags, String

#conversation_idString?

Conversation ID filter used for estimation (tweet_search_extractor)

Parameters:

  • (String)

Returns:

  • (String, nil)


48
# File 'lib/x_twitter_scraper/models/extraction_estimate_cost_params.rb', line 48

optional :conversation_id, String, api_name: :conversationId

#exact_phraseString?

Exact phrase filter for search estimation

Parameters:

  • (String)

Returns:

  • (String, nil)


54
# File 'lib/x_twitter_scraper/models/extraction_estimate_cost_params.rb', line 54

optional :exact_phrase, String, api_name: :exactPhrase

#exclude_wordsString?

Words or quoted phrases excluded from estimated results. Separate with spaces, commas, or lines.

Parameters:

  • (String)

Returns:

  • (String, nil)


61
# File 'lib/x_twitter_scraper/models/extraction_estimate_cost_params.rb', line 61

optional :exclude_words, String, api_name: :excludeWords

#from_userString?

Estimate only tweets from this author username (tweet_search_extractor)

Parameters:

  • (String)

Returns:

  • (String, nil)


67
# File 'lib/x_twitter_scraper/models/extraction_estimate_cost_params.rb', line 67

optional :from_user, String, api_name: :fromUser

#hashtagsString?

Hashtags applied to the estimate, separated by spaces, commas, or lines.

Parameters:

  • (String)

Returns:

  • (String, nil)


73
# File 'lib/x_twitter_scraper/models/extraction_estimate_cost_params.rb', line 73

optional :hashtags, String

#in_reply_to_tweet_idString?

Estimate only replies to this tweet ID (tweet_search_extractor)

Parameters:

  • (String)

Returns:

  • (String, nil)


79
# File 'lib/x_twitter_scraper/models/extraction_estimate_cost_params.rb', line 79

optional :in_reply_to_tweet_id, String, api_name: :inReplyToTweetId

#languageString?

Language code used for estimate filtering (tweet_search_extractor)

Parameters:

  • (String)

Returns:

  • (String, nil)


85
# File 'lib/x_twitter_scraper/models/extraction_estimate_cost_params.rb', line 85

optional :language, String

#list_idString?

Estimate search results within this list ID (tweet_search_extractor)

Parameters:

  • (String)

Returns:

  • (String, nil)


91
# File 'lib/x_twitter_scraper/models/extraction_estimate_cost_params.rb', line 91

optional :list_id, String, api_name: :listId

#media_typeSymbol, ...

Media type used for estimate filtering (tweet_search_extractor)



97
98
99
# File 'lib/x_twitter_scraper/models/extraction_estimate_cost_params.rb', line 97

optional :media_type,
enum: -> { XTwitterScraper::ExtractionEstimateCostParams::MediaType },
api_name: :mediaType

#mentioningString?

Estimate tweets mentioning this username (tweet_search_extractor)

Parameters:

  • (String)

Returns:

  • (String, nil)


105
# File 'lib/x_twitter_scraper/models/extraction_estimate_cost_params.rb', line 105

optional :mentioning, String

#min_favesInteger?

Minimum likes threshold for estimated results (tweet_search_extractor)

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


111
# File 'lib/x_twitter_scraper/models/extraction_estimate_cost_params.rb', line 111

optional :min_faves, Integer, api_name: :minFaves

#min_quotesInteger?

Minimum quote count threshold for estimated results (tweet_search_extractor)

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


117
# File 'lib/x_twitter_scraper/models/extraction_estimate_cost_params.rb', line 117

optional :min_quotes, Integer, api_name: :minQuotes

#min_repliesInteger?

Minimum replies threshold for estimated results (tweet_search_extractor)

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


123
# File 'lib/x_twitter_scraper/models/extraction_estimate_cost_params.rb', line 123

optional :min_replies, Integer, api_name: :minReplies

#min_retweetsInteger?

Minimum retweets threshold for estimated results (tweet_search_extractor)

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


129
# File 'lib/x_twitter_scraper/models/extraction_estimate_cost_params.rb', line 129

optional :min_retweets, Integer, api_name: :minRetweets

#placeString?

Estimate search results within this place ID (tweet_search_extractor)

Parameters:

  • (String)

Returns:

  • (String, nil)


135
# File 'lib/x_twitter_scraper/models/extraction_estimate_cost_params.rb', line 135

optional :place, String

#place_countryString?

Estimate search results within this country code (tweet_search_extractor)

Parameters:

  • (String)

Returns:

  • (String, nil)


141
# File 'lib/x_twitter_scraper/models/extraction_estimate_cost_params.rb', line 141

optional :place_country, String, api_name: :placeCountry

#point_radiusString?

Geo point radius used for estimation, e.g. -73.99 40.73 25mi (tweet_search_extractor)

Parameters:

  • (String)

Returns:

  • (String, nil)


148
# File 'lib/x_twitter_scraper/models/extraction_estimate_cost_params.rb', line 148

optional :point_radius, String, api_name: :pointRadius

#quotesSymbol, ...

Quote mode used for estimation (tweet_search_extractor)



154
# File 'lib/x_twitter_scraper/models/extraction_estimate_cost_params.rb', line 154

optional :quotes, enum: -> { XTwitterScraper::ExtractionEstimateCostParams::Quotes }

#quotes_of_tweet_idString?

Estimate only quotes of this tweet ID (tweet_search_extractor)

Parameters:

  • (String)

Returns:

  • (String, nil)


160
# File 'lib/x_twitter_scraper/models/extraction_estimate_cost_params.rb', line 160

optional :quotes_of_tweet_id, String, api_name: :quotesOfTweetId

#repliesSymbol, ...

Reply mode used for estimation (tweet_search_extractor)



166
# File 'lib/x_twitter_scraper/models/extraction_estimate_cost_params.rb', line 166

optional :replies, enum: -> { XTwitterScraper::ExtractionEstimateCostParams::Replies }

#results_limitInteger?

Maximum number of results to estimate. When set, the estimate caps projected results to this value.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


173
# File 'lib/x_twitter_scraper/models/extraction_estimate_cost_params.rb', line 173

optional :results_limit, Integer, api_name: :resultsLimit

#retweetsSymbol, ...

Retweet mode used for estimation (tweet_search_extractor)



179
# File 'lib/x_twitter_scraper/models/extraction_estimate_cost_params.rb', line 179

optional :retweets, enum: -> { XTwitterScraper::ExtractionEstimateCostParams::Retweets }

#retweets_of_tweet_idString?

Estimate only retweets of this tweet ID (tweet_search_extractor)

Parameters:

  • (String)

Returns:

  • (String, nil)


185
# File 'lib/x_twitter_scraper/models/extraction_estimate_cost_params.rb', line 185

optional :retweets_of_tweet_id, String, api_name: :retweetsOfTweetId

#search_queryString?

Required for tweet_search_extractor & community_search.

Parameters:

  • (String)

Returns:

  • (String, nil)


191
# File 'lib/x_twitter_scraper/models/extraction_estimate_cost_params.rb', line 191

optional :search_query, String, api_name: :searchQuery

#since_dateDate?

Estimate start date in YYYY-MM-DD format (tweet_search_extractor)

Parameters:

  • (Date)

Returns:

  • (Date, nil)


197
# File 'lib/x_twitter_scraper/models/extraction_estimate_cost_params.rb', line 197

optional :since_date, Date, api_name: :sinceDate

#target_community_idString?

Required for community_post_extractor & community_search.

Parameters:

  • (String)

Returns:

  • (String, nil)


203
# File 'lib/x_twitter_scraper/models/extraction_estimate_cost_params.rb', line 203

optional :target_community_id, String, api_name: :targetCommunityId

#target_list_idString?

Required for list_follower_explorer, list_member_extractor & list_post_extractor.

Parameters:

  • (String)

Returns:

  • (String, nil)


210
# File 'lib/x_twitter_scraper/models/extraction_estimate_cost_params.rb', line 210

optional :target_list_id, String, api_name: :targetListId

#target_space_idString?

Required for space_explorer.

Parameters:

  • (String)

Returns:

  • (String, nil)


216
# File 'lib/x_twitter_scraper/models/extraction_estimate_cost_params.rb', line 216

optional :target_space_id, String, api_name: :targetSpaceId

#target_tweet_idString?

Parameters:

  • (String)

Returns:

  • (String, nil)


221
# File 'lib/x_twitter_scraper/models/extraction_estimate_cost_params.rb', line 221

optional :target_tweet_id, String, api_name: :targetTweetId

#target_usernameString?

Parameters:

  • (String)

Returns:

  • (String, nil)


226
# File 'lib/x_twitter_scraper/models/extraction_estimate_cost_params.rb', line 226

optional :target_username, String, api_name: :targetUsername

#to_userString?

Estimate replies sent to this username (tweet_search_extractor)

Parameters:

  • (String)

Returns:

  • (String, nil)


232
# File 'lib/x_twitter_scraper/models/extraction_estimate_cost_params.rb', line 232

optional :to_user, String, api_name: :toUser

#tool_typeSymbol, XTwitterScraper::Models::ExtractionEstimateCostParams::ToolType

Identifier for the extraction tool used to run a job.

Parameters:

  • value (XTwitterScraper::Models::ExtractionEstimateCostParams::tool_type)

Returns:



14
15
16
# File 'lib/x_twitter_scraper/models/extraction_estimate_cost_params.rb', line 14

required :tool_type,
enum: -> { XTwitterScraper::ExtractionEstimateCostParams::ToolType },
api_name: :toolType

#until_dateDate?

Estimate end date in YYYY-MM-DD format (tweet_search_extractor)

Parameters:

  • (Date)

Returns:

  • (Date, nil)


238
# File 'lib/x_twitter_scraper/models/extraction_estimate_cost_params.rb', line 238

optional :until_date, Date, api_name: :untilDate

#urlString?

URL substring or domain filter used for estimation (tweet_search_extractor)

Parameters:

  • (String)

Returns:

  • (String, nil)


244
# File 'lib/x_twitter_scraper/models/extraction_estimate_cost_params.rb', line 244

optional :url, String

#verified_onlyBoolean?

Estimate only verified authors (tweet_search_extractor)

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


250
# File 'lib/x_twitter_scraper/models/extraction_estimate_cost_params.rb', line 250

optional :verified_only, XTwitterScraper::Internal::Type::Boolean, api_name: :verifiedOnly

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/x_twitter_scraper/models/extraction_estimate_cost_params.rb', line 364

Instance Method Details

#to_hash{

Returns:

  • ({)


256
# File 'sig/x_twitter_scraper/models/extraction_estimate_cost_params.rbs', line 256

def to_hash: -> {