Class: XTwitterScraper::Models::ExtractionEstimateCostParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/x_twitter_scraper/models/extraction_estimate_cost_params.rb

Overview

Defined Under Namespace

Modules: ToolType

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(tool_type:, advanced_query: nil, exact_phrase: nil, exclude_words: nil, search_query: nil, target_community_id: nil, target_list_id: nil, target_space_id: nil, target_tweet_id: nil, target_username: nil, request_options: {}) ⇒ Object

Parameters:

  • tool_type (Symbol, XTwitterScraper::Models::ExtractionEstimateCostParams::ToolType)

    Identifier for the extraction tool used to run a job.

  • advanced_query (String) (defaults to: nil)

    Raw advanced query string appended to the estimate (tweet_search_extractor)

  • exact_phrase (String) (defaults to: nil)

    Exact phrase filter for search estimation

  • exclude_words (String) (defaults to: nil)

    Words excluded from estimated search results

  • search_query (String) (defaults to: nil)
  • target_community_id (String) (defaults to: nil)
  • target_list_id (String) (defaults to: nil)
  • target_space_id (String) (defaults to: nil)
  • target_tweet_id (String) (defaults to: nil)
  • target_username (String) (defaults to: nil)
  • request_options (XTwitterScraper::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/x_twitter_scraper/models/extraction_estimate_cost_params.rb', line 66

Instance Attribute Details

#advanced_queryString?

Raw advanced query string appended to the estimate (tweet_search_extractor)

Returns:

  • (String, nil)


22
# File 'lib/x_twitter_scraper/models/extraction_estimate_cost_params.rb', line 22

optional :advanced_query, String, api_name: :advancedQuery

#exact_phraseString?

Exact phrase filter for search estimation

Returns:

  • (String, nil)


28
# File 'lib/x_twitter_scraper/models/extraction_estimate_cost_params.rb', line 28

optional :exact_phrase, String, api_name: :exactPhrase

#exclude_wordsString?

Words excluded from estimated search results

Returns:

  • (String, nil)


34
# File 'lib/x_twitter_scraper/models/extraction_estimate_cost_params.rb', line 34

optional :exclude_words, String, api_name: :excludeWords

#search_queryString?

Returns:

  • (String, nil)


39
# File 'lib/x_twitter_scraper/models/extraction_estimate_cost_params.rb', line 39

optional :search_query, String, api_name: :searchQuery

#target_community_idString?

Returns:

  • (String, nil)


44
# File 'lib/x_twitter_scraper/models/extraction_estimate_cost_params.rb', line 44

optional :target_community_id, String, api_name: :targetCommunityId

#target_list_idString?

Returns:

  • (String, nil)


49
# File 'lib/x_twitter_scraper/models/extraction_estimate_cost_params.rb', line 49

optional :target_list_id, String, api_name: :targetListId

#target_space_idString?

Returns:

  • (String, nil)


54
# File 'lib/x_twitter_scraper/models/extraction_estimate_cost_params.rb', line 54

optional :target_space_id, String, api_name: :targetSpaceId

#target_tweet_idString?

Returns:

  • (String, nil)


59
# File 'lib/x_twitter_scraper/models/extraction_estimate_cost_params.rb', line 59

optional :target_tweet_id, String, api_name: :targetTweetId

#target_usernameString?

Returns:

  • (String, nil)


64
# File 'lib/x_twitter_scraper/models/extraction_estimate_cost_params.rb', line 64

optional :target_username, String, api_name: :targetUsername

#tool_typeSymbol, XTwitterScraper::Models::ExtractionEstimateCostParams::ToolType

Identifier for the extraction tool used to run a job.



14
15
16
# File 'lib/x_twitter_scraper/models/extraction_estimate_cost_params.rb', line 14

required :tool_type,
enum: -> { XTwitterScraper::ExtractionEstimateCostParams::ToolType },
api_name: :toolType