Class: XTwitterScraper::Models::ExtractionEstimateCostParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- XTwitterScraper::Models::ExtractionEstimateCostParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/x_twitter_scraper/models/extraction_estimate_cost_params.rb
Overview
Defined Under Namespace
Modules: ToolType
Instance Attribute Summary collapse
-
#advanced_query ⇒ String?
Raw advanced query string appended to the estimate (tweet_search_extractor).
-
#exact_phrase ⇒ String?
Exact phrase filter for search estimation.
-
#exclude_words ⇒ String?
Words excluded from estimated search results.
- #search_query ⇒ String?
- #target_community_id ⇒ String?
- #target_list_id ⇒ String?
- #target_space_id ⇒ String?
- #target_tweet_id ⇒ String?
- #target_username ⇒ String?
-
#tool_type ⇒ Symbol, XTwitterScraper::Models::ExtractionEstimateCostParams::ToolType
Identifier for the extraction tool used to run a job.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(tool_type:, advanced_query: nil, exact_phrase: nil, exclude_words: nil, search_query: nil, target_community_id: nil, target_list_id: nil, target_space_id: nil, target_tweet_id: nil, target_username: nil, request_options: {}) ⇒ Object
|
|
# File 'lib/x_twitter_scraper/models/extraction_estimate_cost_params.rb', line 66
|
Instance Attribute Details
#advanced_query ⇒ String?
Raw advanced query string appended to the estimate (tweet_search_extractor)
22 |
# File 'lib/x_twitter_scraper/models/extraction_estimate_cost_params.rb', line 22 optional :advanced_query, String, api_name: :advancedQuery |
#exact_phrase ⇒ String?
Exact phrase filter for search estimation
28 |
# File 'lib/x_twitter_scraper/models/extraction_estimate_cost_params.rb', line 28 optional :exact_phrase, String, api_name: :exactPhrase |
#exclude_words ⇒ String?
Words excluded from estimated search results
34 |
# File 'lib/x_twitter_scraper/models/extraction_estimate_cost_params.rb', line 34 optional :exclude_words, String, api_name: :excludeWords |
#search_query ⇒ String?
39 |
# File 'lib/x_twitter_scraper/models/extraction_estimate_cost_params.rb', line 39 optional :search_query, String, api_name: :searchQuery |
#target_community_id ⇒ String?
44 |
# File 'lib/x_twitter_scraper/models/extraction_estimate_cost_params.rb', line 44 optional :target_community_id, String, api_name: :targetCommunityId |
#target_list_id ⇒ String?
49 |
# File 'lib/x_twitter_scraper/models/extraction_estimate_cost_params.rb', line 49 optional :target_list_id, String, api_name: :targetListId |
#target_space_id ⇒ String?
54 |
# File 'lib/x_twitter_scraper/models/extraction_estimate_cost_params.rb', line 54 optional :target_space_id, String, api_name: :targetSpaceId |
#target_tweet_id ⇒ String?
59 |
# File 'lib/x_twitter_scraper/models/extraction_estimate_cost_params.rb', line 59 optional :target_tweet_id, String, api_name: :targetTweetId |
#target_username ⇒ String?
64 |
# File 'lib/x_twitter_scraper/models/extraction_estimate_cost_params.rb', line 64 optional :target_username, String, api_name: :targetUsername |
#tool_type ⇒ Symbol, XTwitterScraper::Models::ExtractionEstimateCostParams::ToolType
Identifier for the extraction tool used to run a job.
14 15 16 |
# File 'lib/x_twitter_scraper/models/extraction_estimate_cost_params.rb', line 14 required :tool_type, enum: -> { XTwitterScraper::ExtractionEstimateCostParams::ToolType }, api_name: :toolType |