Class: XTwitterScraper::Models::ExtractionRunParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- XTwitterScraper::Models::ExtractionRunParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/x_twitter_scraper/models/extraction_run_params.rb,
sig/x_twitter_scraper/models/extraction_run_params.rbs
Overview
Defined Under Namespace
Modules: CollectionStrategy, DedupeMode, MediaType, QueryType, Quotes, Replies, Retweets, Scope, SinceTime, Sort, Target, ToolType, UntilTime Classes: RelationTarget
Constant Summary
Constants included from Internal::Type::RequestParameters
Internal::Type::RequestParameters::XTwitterScraper
Instance Attribute Summary collapse
-
#advanced_query ⇒ String?
Raw advanced search query appended as-is (tweet_search_extractor).
-
#any_words ⇒ String?
Words or quoted phrases where any one can match.
-
#bio_contains ⇒ String?
Bio terms separated by commas or lines.
-
#blue_verified_only ⇒ Boolean?
Return only Blue-verified Tweet authors.
-
#bounding_box ⇒ String?
Geo bounding box, e.g.
-
#card_name ⇒ String?
Match the Tweet card name.
-
#cashtags ⇒ String?
Cashtags separated by spaces, commas, or lines.
-
#collection_strategy ⇒ Symbol, ...
Reply collection strategy.
-
#conversation_id ⇒ String?
Conversation ID filter (tweet_search_extractor).
-
#dedupe_across_targets ⇒ Boolean?
Merge duplicate results across collection targets.
-
#dedupe_mode ⇒ Symbol, ...
Keep target duplicates, first rows, or merged overlap.
-
#dry_run ⇒ Boolean?
Estimate cost without creating an extraction.
-
#exact_phrase ⇒ String?
Exact phrase to match (tweet_search_extractor).
-
#exclude_original_author ⇒ Boolean?
Exclude replies from the source author.
-
#exclude_source ⇒ String?
Exclude a source application.
-
#exclude_words ⇒ String?
Words or quoted phrases to exclude.
-
#from_user ⇒ String?
Filter by author username (tweet_search_extractor).
-
#geocode ⇒ String?
Match latitude, longitude, and radius.
-
#has_location ⇒ Boolean?
Require a profile location.
-
#has_media_only ⇒ Boolean?
Return only replies with media.
-
#has_website ⇒ Boolean?
Require a profile website.
-
#hashtags ⇒ String?
Hashtags separated by spaces, commas, or lines.
-
#in_reply_to_tweet_id ⇒ String?
Only replies to this tweet ID (tweet_search_extractor).
-
#include_original_post ⇒ Boolean?
Include the source post in reply results.
-
#include_search_terms ⇒ Boolean?
Add matching search terms to collection metadata.
-
#include_target_metadata ⇒ Boolean?
Add source target metadata to each result.
-
#language ⇒ String?
Language code filter (tweet_search_extractor).
-
#list_id ⇒ String?
Search within a list ID (tweet_search_extractor).
-
#location_contains ⇒ String?
Required profile location text.
-
#max_depth ⇒ Integer?
Maximum nested reply depth.
-
#max_followers ⇒ Integer?
Maximum follower count for profile results.
-
#max_following ⇒ Integer?
Maximum following count for profile results.
-
#max_id ⇒ String?
Return Tweets older than this Tweet ID.
-
#max_items_per_target ⇒ Integer?
Maximum results collected for each target.
-
#max_likes ⇒ Integer?
Maximum Tweet like count.
-
#max_pages_per_target ⇒ Integer?
Reply pages collected for each target.
-
#max_posts ⇒ Integer?
Maximum post count for profile results.
-
#max_quotes ⇒ Integer?
Maximum Tweet quote count.
-
#max_replies ⇒ Integer?
Maximum Tweet reply count.
-
#max_retweets ⇒ Integer?
Maximum Tweet repost count.
-
#media_type ⇒ Symbol, ...
Media type filter (tweet_search_extractor).
-
#mentioning ⇒ String?
Filter tweets mentioning a username (tweet_search_extractor).
-
#min_account_age_days ⇒ Integer?
Minimum profile age in days.
-
#min_bookmarks ⇒ Integer?
Minimum Tweet bookmark count.
-
#min_faves ⇒ Integer?
Minimum likes threshold (tweet_search_extractor).
-
#min_followers ⇒ Integer?
Minimum follower count for profile results.
-
#min_following ⇒ Integer?
Minimum following count for profile results.
-
#min_posts ⇒ Integer?
Minimum post count for profile results.
-
#min_quotes ⇒ Integer?
Minimum quote count threshold (tweet_search_extractor).
-
#min_replies ⇒ Integer?
Minimum replies threshold (tweet_search_extractor).
-
#min_retweets ⇒ Integer?
Minimum retweets threshold (tweet_search_extractor).
-
#min_views ⇒ Integer?
Minimum Tweet view count.
-
#native_retweets ⇒ Boolean?
Only return native reposts.
-
#near ⇒ String?
Match a place name.
-
#news ⇒ Boolean?
Only return news results.
-
#overlap_mode ⇒ Boolean?
Shortcut for dedupeMode=merge.
-
#place ⇒ String?
Search within a place ID (tweet_search_extractor).
-
#place_country ⇒ String?
Search within a country code (tweet_search_extractor).
-
#point_radius ⇒ String?
Geo point radius, e.g.
-
#query_type ⇒ Symbol, ...
Search ranking applied to every query.
-
#quotes ⇒ Symbol, ...
Quote mode (tweet_search_extractor).
-
#quotes_of_tweet_id ⇒ String?
Only quotes of this tweet ID (tweet_search_extractor).
-
#relation_targets ⇒ Array<XTwitterScraper::Models::ExtractionRunParams::RelationTarget>?
Profile relations processed within one job.
-
#replies ⇒ Symbol, ...
Reply mode (tweet_search_extractor).
-
#results_limit ⇒ Integer?
Maximum number of results to extract.
-
#retweets ⇒ Symbol, ...
Retweet mode (tweet_search_extractor).
-
#retweets_of_tweet_id ⇒ String?
Only retweets of this tweet ID (tweet_search_extractor).
-
#safe ⇒ Boolean?
Enable the safe-search filter.
-
#scope ⇒ Symbol, ...
Reply depth scope.
-
#search_queries ⇒ Array<String>?
Search queries processed as one collection job.
-
#search_query ⇒ String?
Required for tweet_search_extractor & community_search.
-
#since_date ⇒ Date?
Start date YYYY-MM-DD (tweet_search_extractor).
-
#since_id ⇒ String?
Return Tweets newer than this Tweet ID.
-
#since_time ⇒ Time, ...
Reply start time as ISO 8601 or Unix seconds.
-
#sort ⇒ Symbol, ...
Reply result order.
-
#source ⇒ String?
Match the source application.
-
#start_cursor ⇒ String?
Resume one reply target from this cursor.
-
#target_community_id ⇒ String?
Required for community_post_extractor & community_search.
-
#target_community_ids ⇒ Array<String>?
Community IDs processed as one collection job.
-
#target_list_id ⇒ String?
Required for list_follower_explorer, list_member_extractor & list_post_extractor.
-
#target_list_ids ⇒ Array<String>?
List IDs processed as one collection job.
-
#target_space_id ⇒ String?
Required for space_explorer.
- #target_tweet_id ⇒ String?
-
#target_tweet_ids ⇒ Array<String>?
Tweet IDs processed as one collection job.
- #target_username ⇒ String?
-
#target_usernames ⇒ Array<String>?
Usernames processed as one collection job.
-
#targets ⇒ Array<String, XTwitterScraper::Models::ExtractionRunParams::Target::UnionMember1>?
Mixed targets auto-routed within one job.
-
#to_user ⇒ String?
Filter replies sent to a username (tweet_search_extractor).
-
#tool_type ⇒ Symbol, XTwitterScraper::Models::ExtractionRunParams::ToolType
Identifier for the extraction tool used to run a job.
-
#until_date ⇒ Date?
End date YYYY-MM-DD (tweet_search_extractor).
-
#until_time ⇒ Time, ...
Reply end time as ISO 8601 or Unix seconds.
-
#url ⇒ String?
URL substring or domain filter (tweet_search_extractor).
-
#username_contains ⇒ String?
Required username text.
-
#verified_only ⇒ Boolean?
Only verified authors (tweet_search_extractor).
-
#verified_type ⇒ String?
Exact profile verification type.
-
#within ⇒ String?
Set the radius for the near filter.
-
#within_time ⇒ String?
Match Tweets inside a recent time window.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
- .values ⇒ Array<Symbol>
- .variants ⇒ Array(String, XTwitterScraper::Models::ExtractionRunParams::Target::UnionMember1)
Instance Method Summary collapse
-
#initialize(tool_type:, dry_run: nil, advanced_query: nil, any_words: nil, bio_contains: nil, blue_verified_only: nil, bounding_box: nil, card_name: nil, cashtags: nil, collection_strategy: nil, conversation_id: nil, dedupe_across_targets: nil, dedupe_mode: nil, exact_phrase: nil, exclude_original_author: nil, exclude_source: nil, exclude_words: nil, from_user: nil, geocode: nil, hashtags: nil, has_location: nil, has_media_only: nil, has_website: nil, include_original_post: nil, include_search_terms: nil, include_target_metadata: nil, in_reply_to_tweet_id: nil, language: nil, list_id: nil, location_contains: nil, max_depth: nil, max_followers: nil, max_following: nil, max_id: nil, max_items_per_target: nil, max_likes: nil, max_pages_per_target: nil, max_posts: nil, max_quotes: nil, max_replies: nil, max_retweets: nil, media_type: nil, mentioning: nil, min_account_age_days: nil, min_bookmarks: nil, min_faves: nil, min_followers: nil, min_following: nil, min_posts: nil, min_quotes: nil, min_replies: nil, min_retweets: nil, min_views: nil, native_retweets: nil, near: nil, news: nil, overlap_mode: nil, place: nil, place_country: nil, point_radius: nil, query_type: nil, quotes: nil, quotes_of_tweet_id: nil, relation_targets: nil, replies: nil, results_limit: nil, retweets: nil, retweets_of_tweet_id: nil, safe: nil, scope: nil, search_queries: nil, search_query: nil, since_date: nil, since_id: nil, since_time: nil, sort: nil, source: nil, start_cursor: nil, target_community_id: nil, target_community_ids: nil, target_list_id: nil, target_list_ids: nil, targets: nil, target_space_id: nil, target_tweet_id: nil, target_tweet_ids: nil, target_username: nil, target_usernames: nil, to_user: nil, until_date: nil, until_time: nil, url: nil, username_contains: nil, verified_only: nil, verified_type: nil, within: nil, within_time: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see ExtractionRunParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(tool_type:, dry_run: nil, advanced_query: nil, any_words: nil, bio_contains: nil, blue_verified_only: nil, bounding_box: nil, card_name: nil, cashtags: nil, collection_strategy: nil, conversation_id: nil, dedupe_across_targets: nil, dedupe_mode: nil, exact_phrase: nil, exclude_original_author: nil, exclude_source: nil, exclude_words: nil, from_user: nil, geocode: nil, hashtags: nil, has_location: nil, has_media_only: nil, has_website: nil, include_original_post: nil, include_search_terms: nil, include_target_metadata: nil, in_reply_to_tweet_id: nil, language: nil, list_id: nil, location_contains: nil, max_depth: nil, max_followers: nil, max_following: nil, max_id: nil, max_items_per_target: nil, max_likes: nil, max_pages_per_target: nil, max_posts: nil, max_quotes: nil, max_replies: nil, max_retweets: nil, media_type: nil, mentioning: nil, min_account_age_days: nil, min_bookmarks: nil, min_faves: nil, min_followers: nil, min_following: nil, min_posts: nil, min_quotes: nil, min_replies: nil, min_retweets: nil, min_views: nil, native_retweets: nil, near: nil, news: nil, overlap_mode: nil, place: nil, place_country: nil, point_radius: nil, query_type: nil, quotes: nil, quotes_of_tweet_id: nil, relation_targets: nil, replies: nil, results_limit: nil, retweets: nil, retweets_of_tweet_id: nil, safe: nil, scope: nil, search_queries: nil, search_query: nil, since_date: nil, since_id: nil, since_time: nil, sort: nil, source: nil, start_cursor: nil, target_community_id: nil, target_community_ids: nil, target_list_id: nil, target_list_ids: nil, targets: nil, target_space_id: nil, target_tweet_id: nil, target_tweet_ids: nil, target_username: nil, target_usernames: nil, to_user: nil, until_date: nil, until_time: nil, url: nil, username_contains: nil, verified_only: nil, verified_type: nil, within: nil, within_time: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see XTwitterScraper::Models::ExtractionRunParams for more details.
|
|
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 625
|
Instance Attribute Details
#advanced_query ⇒ String?
Raw advanced search query appended as-is (tweet_search_extractor)
30 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 30 optional :advanced_query, String, api_name: :advancedQuery |
#any_words ⇒ String?
Words or quoted phrases where any one can match. Separate with spaces, commas, or lines. (tweet_search_extractor)
37 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 37 optional :any_words, String, api_name: :anyWords |
#bio_contains ⇒ String?
Bio terms separated by commas or lines.
43 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 43 optional :bio_contains, String, api_name: :bioContains |
#blue_verified_only ⇒ Boolean?
Return only Blue-verified Tweet authors.
49 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 49 optional :blue_verified_only, XTwitterScraper::Internal::Type::Boolean, api_name: :blueVerifiedOnly |
#bounding_box ⇒ String?
Geo bounding box, e.g. -74.1 40.6 -73.9 40.8 (tweet_search_extractor)
55 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 55 optional :bounding_box, String, api_name: :boundingBox |
#card_name ⇒ String?
Match the Tweet card name.
61 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 61 optional :card_name, String, api_name: :cardName |
#cashtags ⇒ String?
Cashtags separated by spaces, commas, or lines. (tweet_search_extractor)
67 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 67 optional :cashtags, String |
#collection_strategy ⇒ Symbol, ...
Reply collection strategy.
73 74 75 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 73 optional :collection_strategy, enum: -> { XTwitterScraper::ExtractionRunParams::CollectionStrategy }, api_name: :collectionStrategy |
#conversation_id ⇒ String?
Conversation ID filter (tweet_search_extractor)
81 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 81 optional :conversation_id, String, api_name: :conversationId |
#dedupe_across_targets ⇒ Boolean?
Merge duplicate results across collection targets.
87 88 89 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 87 optional :dedupe_across_targets, XTwitterScraper::Internal::Type::Boolean, api_name: :dedupeAcrossTargets |
#dedupe_mode ⇒ Symbol, ...
Keep target duplicates, first rows, or merged overlap.
95 96 97 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 95 optional :dedupe_mode, enum: -> { XTwitterScraper::ExtractionRunParams::DedupeMode }, api_name: :dedupeMode |
#dry_run ⇒ Boolean?
Estimate cost without creating an extraction.
24 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 24 optional :dry_run, XTwitterScraper::Internal::Type::Boolean |
#exact_phrase ⇒ String?
Exact phrase to match (tweet_search_extractor)
103 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 103 optional :exact_phrase, String, api_name: :exactPhrase |
#exclude_original_author ⇒ Boolean?
Exclude replies from the source author.
109 110 111 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 109 optional :exclude_original_author, XTwitterScraper::Internal::Type::Boolean, api_name: :excludeOriginalAuthor |
#exclude_source ⇒ String?
Exclude a source application.
117 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 117 optional :exclude_source, String, api_name: :excludeSource |
#exclude_words ⇒ String?
Words or quoted phrases to exclude. Separate with spaces, commas, or lines. (tweet_search_extractor)
124 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 124 optional :exclude_words, String, api_name: :excludeWords |
#from_user ⇒ String?
Filter by author username (tweet_search_extractor)
130 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 130 optional :from_user, String, api_name: :fromUser |
#geocode ⇒ String?
Match latitude, longitude, and radius.
136 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 136 optional :geocode, String |
#has_location ⇒ Boolean?
Require a profile location.
148 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 148 optional :has_location, XTwitterScraper::Internal::Type::Boolean, api_name: :hasLocation |
#has_media_only ⇒ Boolean?
Return only replies with media.
154 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 154 optional :has_media_only, XTwitterScraper::Internal::Type::Boolean, api_name: :hasMediaOnly |
#has_website ⇒ Boolean?
Require a profile website.
160 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 160 optional :has_website, XTwitterScraper::Internal::Type::Boolean, api_name: :hasWebsite |
#hashtags ⇒ String?
Hashtags separated by spaces, commas, or lines. (tweet_search_extractor)
142 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 142 optional :hashtags, String |
#in_reply_to_tweet_id ⇒ String?
Only replies to this tweet ID (tweet_search_extractor)
188 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 188 optional :in_reply_to_tweet_id, String, api_name: :inReplyToTweetId |
#include_original_post ⇒ Boolean?
Include the source post in reply results.
166 167 168 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 166 optional :include_original_post, XTwitterScraper::Internal::Type::Boolean, api_name: :includeOriginalPost |
#include_search_terms ⇒ Boolean?
Add matching search terms to collection metadata.
174 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 174 optional :include_search_terms, XTwitterScraper::Internal::Type::Boolean, api_name: :includeSearchTerms |
#include_target_metadata ⇒ Boolean?
Add source target metadata to each result.
180 181 182 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 180 optional :include_target_metadata, XTwitterScraper::Internal::Type::Boolean, api_name: :includeTargetMetadata |
#language ⇒ String?
Language code filter (tweet_search_extractor)
194 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 194 optional :language, String |
#list_id ⇒ String?
Search within a list ID (tweet_search_extractor)
200 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 200 optional :list_id, String, api_name: :listId |
#location_contains ⇒ String?
Required profile location text.
206 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 206 optional :location_contains, String, api_name: :locationContains |
#max_depth ⇒ Integer?
Maximum nested reply depth.
212 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 212 optional :max_depth, Integer, api_name: :maxDepth |
#max_followers ⇒ Integer?
Maximum follower count for profile results.
218 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 218 optional :max_followers, Integer, api_name: :maxFollowers |
#max_following ⇒ Integer?
Maximum following count for profile results.
224 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 224 optional :max_following, Integer, api_name: :maxFollowing |
#max_id ⇒ String?
Return Tweets older than this Tweet ID.
230 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 230 optional :max_id, String, api_name: :maxId |
#max_items_per_target ⇒ Integer?
Maximum results collected for each target.
236 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 236 optional :max_items_per_target, Integer, api_name: :maxItemsPerTarget |
#max_likes ⇒ Integer?
Maximum Tweet like count.
242 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 242 optional :max_likes, Integer, api_name: :maxLikes |
#max_pages_per_target ⇒ Integer?
Reply pages collected for each target.
248 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 248 optional :max_pages_per_target, Integer, api_name: :maxPagesPerTarget |
#max_posts ⇒ Integer?
Maximum post count for profile results.
254 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 254 optional :max_posts, Integer, api_name: :maxPosts |
#max_quotes ⇒ Integer?
Maximum Tweet quote count.
260 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 260 optional :max_quotes, Integer, api_name: :maxQuotes |
#max_replies ⇒ Integer?
Maximum Tweet reply count.
266 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 266 optional :max_replies, Integer, api_name: :maxReplies |
#max_retweets ⇒ Integer?
Maximum Tweet repost count.
272 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 272 optional :max_retweets, Integer, api_name: :maxRetweets |
#media_type ⇒ Symbol, ...
Media type filter (tweet_search_extractor)
278 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 278 optional :media_type, enum: -> { XTwitterScraper::ExtractionRunParams::MediaType }, api_name: :mediaType |
#mentioning ⇒ String?
Filter tweets mentioning a username (tweet_search_extractor)
284 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 284 optional :mentioning, String |
#min_account_age_days ⇒ Integer?
Minimum profile age in days.
290 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 290 optional :min_account_age_days, Integer, api_name: :minAccountAgeDays |
#min_bookmarks ⇒ Integer?
Minimum Tweet bookmark count.
296 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 296 optional :min_bookmarks, Integer, api_name: :minBookmarks |
#min_faves ⇒ Integer?
Minimum likes threshold (tweet_search_extractor)
302 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 302 optional :min_faves, Integer, api_name: :minFaves |
#min_followers ⇒ Integer?
Minimum follower count for profile results.
308 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 308 optional :min_followers, Integer, api_name: :minFollowers |
#min_following ⇒ Integer?
Minimum following count for profile results.
314 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 314 optional :min_following, Integer, api_name: :minFollowing |
#min_posts ⇒ Integer?
Minimum post count for profile results.
320 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 320 optional :min_posts, Integer, api_name: :minPosts |
#min_quotes ⇒ Integer?
Minimum quote count threshold (tweet_search_extractor)
326 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 326 optional :min_quotes, Integer, api_name: :minQuotes |
#min_replies ⇒ Integer?
Minimum replies threshold (tweet_search_extractor)
332 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 332 optional :min_replies, Integer, api_name: :minReplies |
#min_retweets ⇒ Integer?
Minimum retweets threshold (tweet_search_extractor)
338 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 338 optional :min_retweets, Integer, api_name: :minRetweets |
#min_views ⇒ Integer?
Minimum Tweet view count.
344 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 344 optional :min_views, Integer, api_name: :minViews |
#native_retweets ⇒ Boolean?
Only return native reposts.
350 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 350 optional :native_retweets, XTwitterScraper::Internal::Type::Boolean, api_name: :nativeRetweets |
#near ⇒ String?
Match a place name.
356 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 356 optional :near, String |
#news ⇒ Boolean?
Only return news results.
362 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 362 optional :news, XTwitterScraper::Internal::Type::Boolean |
#overlap_mode ⇒ Boolean?
Shortcut for dedupeMode=merge.
368 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 368 optional :overlap_mode, XTwitterScraper::Internal::Type::Boolean, api_name: :overlapMode |
#place ⇒ String?
Search within a place ID (tweet_search_extractor)
374 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 374 optional :place, String |
#place_country ⇒ String?
Search within a country code (tweet_search_extractor)
380 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 380 optional :place_country, String, api_name: :placeCountry |
#point_radius ⇒ String?
Geo point radius, e.g. -73.99 40.73 25mi (tweet_search_extractor)
386 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 386 optional :point_radius, String, api_name: :pointRadius |
#query_type ⇒ Symbol, ...
Search ranking applied to every query.
392 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 392 optional :query_type, enum: -> { XTwitterScraper::ExtractionRunParams::QueryType }, api_name: :queryType |
#quotes ⇒ Symbol, ...
Quote mode (tweet_search_extractor)
398 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 398 optional :quotes, enum: -> { XTwitterScraper::ExtractionRunParams::Quotes } |
#quotes_of_tweet_id ⇒ String?
Only quotes of this tweet ID (tweet_search_extractor)
404 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 404 optional :quotes_of_tweet_id, String, api_name: :quotesOfTweetId |
#relation_targets ⇒ Array<XTwitterScraper::Models::ExtractionRunParams::RelationTarget>?
Profile relations processed within one job.
410 411 412 413 414 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 410 optional :relation_targets, -> { XTwitterScraper::Internal::Type::ArrayOf[XTwitterScraper::ExtractionRunParams::RelationTarget] }, api_name: :relationTargets |
#replies ⇒ Symbol, ...
Reply mode (tweet_search_extractor)
420 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 420 optional :replies, enum: -> { XTwitterScraper::ExtractionRunParams::Replies } |
#results_limit ⇒ Integer?
Maximum number of results to extract. When set, the extraction stops after reaching this limit.
427 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 427 optional :results_limit, Integer, api_name: :resultsLimit |
#retweets ⇒ Symbol, ...
Retweet mode (tweet_search_extractor)
433 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 433 optional :retweets, enum: -> { XTwitterScraper::ExtractionRunParams::Retweets } |
#retweets_of_tweet_id ⇒ String?
Only retweets of this tweet ID (tweet_search_extractor)
439 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 439 optional :retweets_of_tweet_id, String, api_name: :retweetsOfTweetId |
#safe ⇒ Boolean?
Enable the safe-search filter.
445 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 445 optional :safe, XTwitterScraper::Internal::Type::Boolean |
#scope ⇒ Symbol, ...
Reply depth scope.
451 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 451 optional :scope, enum: -> { XTwitterScraper::ExtractionRunParams::Scope } |
#search_queries ⇒ Array<String>?
Search queries processed as one collection job.
457 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 457 optional :search_queries, XTwitterScraper::Internal::Type::ArrayOf[String], api_name: :searchQueries |
#search_query ⇒ String?
Required for tweet_search_extractor & community_search.
463 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 463 optional :search_query, String, api_name: :searchQuery |
#since_date ⇒ Date?
Start date YYYY-MM-DD (tweet_search_extractor)
469 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 469 optional :since_date, Date, api_name: :sinceDate |
#since_id ⇒ String?
Return Tweets newer than this Tweet ID.
475 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 475 optional :since_id, String, api_name: :sinceId |
#since_time ⇒ Time, ...
Reply start time as ISO 8601 or Unix seconds.
481 482 483 484 485 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 481 optional :since_time, union: -> { XTwitterScraper::ExtractionRunParams::SinceTime }, api_name: :sinceTime |
#sort ⇒ Symbol, ...
Reply result order.
491 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 491 optional :sort, enum: -> { XTwitterScraper::ExtractionRunParams::Sort } |
#source ⇒ String?
Match the source application.
497 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 497 optional :source, String |
#start_cursor ⇒ String?
Resume one reply target from this cursor.
503 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 503 optional :start_cursor, String, api_name: :startCursor |
#target_community_id ⇒ String?
Required for community_post_extractor & community_search.
509 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 509 optional :target_community_id, String, api_name: :targetCommunityId |
#target_community_ids ⇒ Array<String>?
Community IDs processed as one collection job.
515 516 517 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 515 optional :target_community_ids, XTwitterScraper::Internal::Type::ArrayOf[String], api_name: :targetCommunityIds |
#target_list_id ⇒ String?
Required for list_follower_explorer, list_member_extractor & list_post_extractor.
524 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 524 optional :target_list_id, String, api_name: :targetListId |
#target_list_ids ⇒ Array<String>?
List IDs processed as one collection job.
530 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 530 optional :target_list_ids, XTwitterScraper::Internal::Type::ArrayOf[String], api_name: :targetListIds |
#target_space_id ⇒ String?
Required for space_explorer.
543 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 543 optional :target_space_id, String, api_name: :targetSpaceId |
#target_tweet_id ⇒ String?
548 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 548 optional :target_tweet_id, String, api_name: :targetTweetId |
#target_tweet_ids ⇒ Array<String>?
Tweet IDs processed as one collection job.
554 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 554 optional :target_tweet_ids, XTwitterScraper::Internal::Type::ArrayOf[String], api_name: :targetTweetIds |
#target_username ⇒ String?
559 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 559 optional :target_username, String, api_name: :targetUsername |
#target_usernames ⇒ Array<String>?
Usernames processed as one collection job.
565 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 565 optional :target_usernames, XTwitterScraper::Internal::Type::ArrayOf[String], api_name: :targetUsernames |
#targets ⇒ Array<String, XTwitterScraper::Models::ExtractionRunParams::Target::UnionMember1>?
Mixed targets auto-routed within one job.
536 537 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 536 optional :targets, -> { XTwitterScraper::Internal::Type::ArrayOf[union: XTwitterScraper::ExtractionRunParams::Target] } |
#to_user ⇒ String?
Filter replies sent to a username (tweet_search_extractor)
571 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 571 optional :to_user, String, api_name: :toUser |
#tool_type ⇒ Symbol, XTwitterScraper::Models::ExtractionRunParams::ToolType
Identifier for the extraction tool used to run a job.
18 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 18 required :tool_type, enum: -> { XTwitterScraper::ExtractionRunParams::ToolType }, api_name: :toolType |
#until_date ⇒ Date?
End date YYYY-MM-DD (tweet_search_extractor)
577 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 577 optional :until_date, Date, api_name: :untilDate |
#until_time ⇒ Time, ...
Reply end time as ISO 8601 or Unix seconds.
583 584 585 586 587 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 583 optional :until_time, union: -> { XTwitterScraper::ExtractionRunParams::UntilTime }, api_name: :untilTime |
#url ⇒ String?
URL substring or domain filter (tweet_search_extractor)
593 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 593 optional :url, String |
#username_contains ⇒ String?
Required username text.
599 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 599 optional :username_contains, String, api_name: :usernameContains |
#verified_only ⇒ Boolean?
Only verified authors (tweet_search_extractor)
605 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 605 optional :verified_only, XTwitterScraper::Internal::Type::Boolean, api_name: :verifiedOnly |
#verified_type ⇒ String?
Exact profile verification type.
611 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 611 optional :verified_type, String, api_name: :verifiedType |
#within ⇒ String?
Set the radius for the near filter.
617 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 617 optional :within, String |
#within_time ⇒ String?
Match Tweets inside a recent time window.
623 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 623 optional :within_time, String, api_name: :withinTime |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 853
|
.variants ⇒ Array(String, XTwitterScraper::Models::ExtractionRunParams::Target::UnionMember1)
|
|
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 999
|
Instance Method Details
#to_hash ⇒ {
626 |
# File 'sig/x_twitter_scraper/models/extraction_run_params.rbs', line 626
def to_hash: -> {
|