Class: XTwitterScraper::Models::ExtractionRunParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/x_twitter_scraper/models/extraction_run_params.rb,
sig/x_twitter_scraper/models/extraction_run_params.rbs

Overview

See Also:

  • XTwitterScraper::Resources::Extractions#run

Defined Under Namespace

Modules: MediaType, Quotes, Replies, Retweets, ToolType

Constant Summary

Constants included from Internal::Type::RequestParameters

Internal::Type::RequestParameters::XTwitterScraper

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(tool_type:, advanced_query: nil, any_words: nil, bounding_box: nil, cashtags: nil, conversation_id: nil, exact_phrase: nil, exclude_words: nil, from_user: nil, hashtags: nil, in_reply_to_tweet_id: nil, language: nil, list_id: nil, media_type: nil, mentioning: nil, min_faves: nil, min_quotes: nil, min_replies: nil, min_retweets: nil, place: nil, place_country: nil, point_radius: nil, quotes: nil, quotes_of_tweet_id: nil, replies: nil, results_limit: nil, retweets: nil, retweets_of_tweet_id: nil, search_query: nil, since_date: nil, target_community_id: nil, target_list_id: nil, target_space_id: nil, target_tweet_id: nil, target_username: nil, to_user: nil, until_date: nil, url: nil, verified_only: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see XTwitterScraper::Models::ExtractionRunParams for more details.

Parameters:

  • tool_type (Symbol, XTwitterScraper::Models::ExtractionRunParams::ToolType)

    Identifier for the extraction tool used to run a job.

  • advanced_query (String) (defaults to: nil)

    Raw advanced search query appended as-is (tweet_search_extractor)

  • any_words (String) (defaults to: nil)

    Words or quoted phrases where any one can match. Separate with spaces, commas, o

  • bounding_box (String) (defaults to: nil)

    Geo bounding box, e.g. -74.1 40.6 -73.9 40.8 (tweet_search_extractor)

  • cashtags (String) (defaults to: nil)

    Cashtags separated by spaces, commas, or lines. (tweet_search_extractor)

  • conversation_id (String) (defaults to: nil)

    Conversation ID filter (tweet_search_extractor)

  • exact_phrase (String) (defaults to: nil)

    Exact phrase to match (tweet_search_extractor)

  • exclude_words (String) (defaults to: nil)

    Words or quoted phrases to exclude. Separate with spaces, commas, or lines. (twe

  • from_user (String) (defaults to: nil)

    Filter by author username (tweet_search_extractor)

  • hashtags (String) (defaults to: nil)

    Hashtags separated by spaces, commas, or lines. (tweet_search_extractor)

  • in_reply_to_tweet_id (String) (defaults to: nil)

    Only replies to this tweet ID (tweet_search_extractor)

  • language (String) (defaults to: nil)

    Language code filter (tweet_search_extractor)

  • list_id (String) (defaults to: nil)

    Search within a list ID (tweet_search_extractor)

  • media_type (Symbol, XTwitterScraper::Models::ExtractionRunParams::MediaType) (defaults to: nil)

    Media type filter (tweet_search_extractor)

  • mentioning (String) (defaults to: nil)

    Filter tweets mentioning a username (tweet_search_extractor)

  • min_faves (Integer) (defaults to: nil)

    Minimum likes threshold (tweet_search_extractor)

  • min_quotes (Integer) (defaults to: nil)

    Minimum quote count threshold (tweet_search_extractor)

  • min_replies (Integer) (defaults to: nil)

    Minimum replies threshold (tweet_search_extractor)

  • min_retweets (Integer) (defaults to: nil)

    Minimum retweets threshold (tweet_search_extractor)

  • place (String) (defaults to: nil)

    Search within a place ID (tweet_search_extractor)

  • place_country (String) (defaults to: nil)

    Search within a country code (tweet_search_extractor)

  • point_radius (String) (defaults to: nil)

    Geo point radius, e.g. -73.99 40.73 25mi (tweet_search_extractor)

  • quotes (Symbol, XTwitterScraper::Models::ExtractionRunParams::Quotes) (defaults to: nil)

    Quote mode (tweet_search_extractor)

  • quotes_of_tweet_id (String) (defaults to: nil)

    Only quotes of this tweet ID (tweet_search_extractor)

  • replies (Symbol, XTwitterScraper::Models::ExtractionRunParams::Replies) (defaults to: nil)

    Reply mode (tweet_search_extractor)

  • results_limit (Integer) (defaults to: nil)

    Maximum number of results to extract. When set, the extraction stops after reach

  • retweets (Symbol, XTwitterScraper::Models::ExtractionRunParams::Retweets) (defaults to: nil)

    Retweet mode (tweet_search_extractor)

  • retweets_of_tweet_id (String) (defaults to: nil)

    Only retweets of this tweet ID (tweet_search_extractor)

  • search_query (String) (defaults to: nil)

    Required for tweet_search_extractor & community_search.

  • since_date (Date) (defaults to: nil)

    Start date YYYY-MM-DD (tweet_search_extractor)

  • target_community_id (String) (defaults to: nil)

    Required for community_post_extractor & community_search.

  • target_list_id (String) (defaults to: nil)

    Required for list_follower_explorer, list_member_extractor & list_post_extractor

  • target_space_id (String) (defaults to: nil)

    Required for space_explorer.

  • target_tweet_id (String) (defaults to: nil)
  • target_username (String) (defaults to: nil)
  • to_user (String) (defaults to: nil)

    Filter replies sent to a username (tweet_search_extractor)

  • until_date (Date) (defaults to: nil)

    End date YYYY-MM-DD (tweet_search_extractor)

  • url (String) (defaults to: nil)

    URL substring or domain filter (tweet_search_extractor)

  • verified_only (Boolean) (defaults to: nil)

    Only verified authors (tweet_search_extractor)

  • request_options (XTwitterScraper::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 246

Instance Attribute Details

#advanced_queryString?

Raw advanced search query appended as-is (tweet_search_extractor)

Parameters:

  • (String)

Returns:

  • (String, nil)


20
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 20

optional :advanced_query, String, api_name: :advancedQuery

#any_wordsString?

Words or quoted phrases where any one can match. Separate with spaces, commas, or lines. (tweet_search_extractor)

Parameters:

  • (String)

Returns:

  • (String, nil)


27
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 27

optional :any_words, String, api_name: :anyWords

#bounding_boxString?

Geo bounding box, e.g. -74.1 40.6 -73.9 40.8 (tweet_search_extractor)

Parameters:

  • (String)

Returns:

  • (String, nil)


33
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 33

optional :bounding_box, String, api_name: :boundingBox

#cashtagsString?

Cashtags separated by spaces, commas, or lines. (tweet_search_extractor)

Parameters:

  • (String)

Returns:

  • (String, nil)


39
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 39

optional :cashtags, String

#conversation_idString?

Conversation ID filter (tweet_search_extractor)

Parameters:

  • (String)

Returns:

  • (String, nil)


45
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 45

optional :conversation_id, String, api_name: :conversationId

#exact_phraseString?

Exact phrase to match (tweet_search_extractor)

Parameters:

  • (String)

Returns:

  • (String, nil)


51
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 51

optional :exact_phrase, String, api_name: :exactPhrase

#exclude_wordsString?

Words or quoted phrases to exclude. Separate with spaces, commas, or lines. (tweet_search_extractor)

Parameters:

  • (String)

Returns:

  • (String, nil)


58
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 58

optional :exclude_words, String, api_name: :excludeWords

#from_userString?

Filter by author username (tweet_search_extractor)

Parameters:

  • (String)

Returns:

  • (String, nil)


64
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 64

optional :from_user, String, api_name: :fromUser

#hashtagsString?

Hashtags separated by spaces, commas, or lines. (tweet_search_extractor)

Parameters:

  • (String)

Returns:

  • (String, nil)


70
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 70

optional :hashtags, String

#in_reply_to_tweet_idString?

Only replies to this tweet ID (tweet_search_extractor)

Parameters:

  • (String)

Returns:

  • (String, nil)


76
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 76

optional :in_reply_to_tweet_id, String, api_name: :inReplyToTweetId

#languageString?

Language code filter (tweet_search_extractor)

Parameters:

  • (String)

Returns:

  • (String, nil)


82
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 82

optional :language, String

#list_idString?

Search within a list ID (tweet_search_extractor)

Parameters:

  • (String)

Returns:

  • (String, nil)


88
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 88

optional :list_id, String, api_name: :listId

#media_typeSymbol, ...

Media type filter (tweet_search_extractor)



94
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 94

optional :media_type, enum: -> { XTwitterScraper::ExtractionRunParams::MediaType }, api_name: :mediaType

#mentioningString?

Filter tweets mentioning a username (tweet_search_extractor)

Parameters:

  • (String)

Returns:

  • (String, nil)


100
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 100

optional :mentioning, String

#min_favesInteger?

Minimum likes threshold (tweet_search_extractor)

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


106
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 106

optional :min_faves, Integer, api_name: :minFaves

#min_quotesInteger?

Minimum quote count threshold (tweet_search_extractor)

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


112
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 112

optional :min_quotes, Integer, api_name: :minQuotes

#min_repliesInteger?

Minimum replies threshold (tweet_search_extractor)

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


118
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 118

optional :min_replies, Integer, api_name: :minReplies

#min_retweetsInteger?

Minimum retweets threshold (tweet_search_extractor)

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


124
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 124

optional :min_retweets, Integer, api_name: :minRetweets

#placeString?

Search within a place ID (tweet_search_extractor)

Parameters:

  • (String)

Returns:

  • (String, nil)


130
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 130

optional :place, String

#place_countryString?

Search within a country code (tweet_search_extractor)

Parameters:

  • (String)

Returns:

  • (String, nil)


136
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 136

optional :place_country, String, api_name: :placeCountry

#point_radiusString?

Geo point radius, e.g. -73.99 40.73 25mi (tweet_search_extractor)

Parameters:

  • (String)

Returns:

  • (String, nil)


142
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 142

optional :point_radius, String, api_name: :pointRadius

#quotesSymbol, ...

Quote mode (tweet_search_extractor)



148
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 148

optional :quotes, enum: -> { XTwitterScraper::ExtractionRunParams::Quotes }

#quotes_of_tweet_idString?

Only quotes of this tweet ID (tweet_search_extractor)

Parameters:

  • (String)

Returns:

  • (String, nil)


154
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 154

optional :quotes_of_tweet_id, String, api_name: :quotesOfTweetId

#repliesSymbol, ...

Reply mode (tweet_search_extractor)



160
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 160

optional :replies, enum: -> { XTwitterScraper::ExtractionRunParams::Replies }

#results_limitInteger?

Maximum number of results to extract. When set, the extraction stops after reaching this limit.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


167
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 167

optional :results_limit, Integer, api_name: :resultsLimit

#retweetsSymbol, ...

Retweet mode (tweet_search_extractor)



173
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 173

optional :retweets, enum: -> { XTwitterScraper::ExtractionRunParams::Retweets }

#retweets_of_tweet_idString?

Only retweets of this tweet ID (tweet_search_extractor)

Parameters:

  • (String)

Returns:

  • (String, nil)


179
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 179

optional :retweets_of_tweet_id, String, api_name: :retweetsOfTweetId

#search_queryString?

Required for tweet_search_extractor & community_search.

Parameters:

  • (String)

Returns:

  • (String, nil)


185
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 185

optional :search_query, String, api_name: :searchQuery

#since_dateDate?

Start date YYYY-MM-DD (tweet_search_extractor)

Parameters:

  • (Date)

Returns:

  • (Date, nil)


191
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 191

optional :since_date, Date, api_name: :sinceDate

#target_community_idString?

Required for community_post_extractor & community_search.

Parameters:

  • (String)

Returns:

  • (String, nil)


197
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 197

optional :target_community_id, String, api_name: :targetCommunityId

#target_list_idString?

Required for list_follower_explorer, list_member_extractor & list_post_extractor.

Parameters:

  • (String)

Returns:

  • (String, nil)


204
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 204

optional :target_list_id, String, api_name: :targetListId

#target_space_idString?

Required for space_explorer.

Parameters:

  • (String)

Returns:

  • (String, nil)


210
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 210

optional :target_space_id, String, api_name: :targetSpaceId

#target_tweet_idString?

Parameters:

  • (String)

Returns:

  • (String, nil)


215
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 215

optional :target_tweet_id, String, api_name: :targetTweetId

#target_usernameString?

Parameters:

  • (String)

Returns:

  • (String, nil)


220
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 220

optional :target_username, String, api_name: :targetUsername

#to_userString?

Filter replies sent to a username (tweet_search_extractor)

Parameters:

  • (String)

Returns:

  • (String, nil)


226
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 226

optional :to_user, String, api_name: :toUser

#tool_typeSymbol, XTwitterScraper::Models::ExtractionRunParams::ToolType

Identifier for the extraction tool used to run a job.

Parameters:

  • value (XTwitterScraper::Models::ExtractionRunParams::tool_type)

Returns:



14
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 14

required :tool_type, enum: -> { XTwitterScraper::ExtractionRunParams::ToolType }, api_name: :toolType

#until_dateDate?

End date YYYY-MM-DD (tweet_search_extractor)

Parameters:

  • (Date)

Returns:

  • (Date, nil)


232
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 232

optional :until_date, Date, api_name: :untilDate

#urlString?

URL substring or domain filter (tweet_search_extractor)

Parameters:

  • (String)

Returns:

  • (String, nil)


238
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 238

optional :url, String

#verified_onlyBoolean?

Only verified authors (tweet_search_extractor)

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


244
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 244

optional :verified_only, XTwitterScraper::Internal::Type::Boolean, api_name: :verifiedOnly

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 358

Instance Method Details

#to_hash{

Returns:

  • ({)


256
# File 'sig/x_twitter_scraper/models/extraction_run_params.rbs', line 256

def to_hash: -> {