Class: XTwitterScraper::Models::ExtractionRunParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- XTwitterScraper::Models::ExtractionRunParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/x_twitter_scraper/models/extraction_run_params.rb,
sig/x_twitter_scraper/models/extraction_run_params.rbs
Overview
Defined Under Namespace
Modules: MediaType, Quotes, Replies, Retweets, ToolType
Constant Summary
Constants included from Internal::Type::RequestParameters
Internal::Type::RequestParameters::XTwitterScraper
Instance Attribute Summary collapse
-
#advanced_query ⇒ String?
Raw advanced search query appended as-is (tweet_search_extractor).
-
#any_words ⇒ String?
Words or quoted phrases where any one can match.
-
#bounding_box ⇒ String?
Geo bounding box, e.g.
-
#cashtags ⇒ String?
Cashtags separated by spaces, commas, or lines.
-
#conversation_id ⇒ String?
Conversation ID filter (tweet_search_extractor).
-
#exact_phrase ⇒ String?
Exact phrase to match (tweet_search_extractor).
-
#exclude_words ⇒ String?
Words or quoted phrases to exclude.
-
#from_user ⇒ String?
Filter by author username (tweet_search_extractor).
-
#hashtags ⇒ String?
Hashtags separated by spaces, commas, or lines.
-
#in_reply_to_tweet_id ⇒ String?
Only replies to this tweet ID (tweet_search_extractor).
-
#language ⇒ String?
Language code filter (tweet_search_extractor).
-
#list_id ⇒ String?
Search within a list ID (tweet_search_extractor).
-
#media_type ⇒ Symbol, ...
Media type filter (tweet_search_extractor).
-
#mentioning ⇒ String?
Filter tweets mentioning a username (tweet_search_extractor).
-
#min_faves ⇒ Integer?
Minimum likes threshold (tweet_search_extractor).
-
#min_quotes ⇒ Integer?
Minimum quote count threshold (tweet_search_extractor).
-
#min_replies ⇒ Integer?
Minimum replies threshold (tweet_search_extractor).
-
#min_retweets ⇒ Integer?
Minimum retweets threshold (tweet_search_extractor).
-
#place ⇒ String?
Search within a place ID (tweet_search_extractor).
-
#place_country ⇒ String?
Search within a country code (tweet_search_extractor).
-
#point_radius ⇒ String?
Geo point radius, e.g.
-
#quotes ⇒ Symbol, ...
Quote mode (tweet_search_extractor).
-
#quotes_of_tweet_id ⇒ String?
Only quotes of this tweet ID (tweet_search_extractor).
-
#replies ⇒ Symbol, ...
Reply mode (tweet_search_extractor).
-
#results_limit ⇒ Integer?
Maximum number of results to extract.
-
#retweets ⇒ Symbol, ...
Retweet mode (tweet_search_extractor).
-
#retweets_of_tweet_id ⇒ String?
Only retweets of this tweet ID (tweet_search_extractor).
-
#search_query ⇒ String?
Required for tweet_search_extractor & community_search.
-
#since_date ⇒ Date?
Start date YYYY-MM-DD (tweet_search_extractor).
-
#target_community_id ⇒ String?
Required for community_post_extractor & community_search.
-
#target_list_id ⇒ String?
Required for list_follower_explorer, list_member_extractor & list_post_extractor.
-
#target_space_id ⇒ String?
Required for space_explorer.
- #target_tweet_id ⇒ String?
- #target_username ⇒ String?
-
#to_user ⇒ String?
Filter replies sent to a username (tweet_search_extractor).
-
#tool_type ⇒ Symbol, XTwitterScraper::Models::ExtractionRunParams::ToolType
Identifier for the extraction tool used to run a job.
-
#until_date ⇒ Date?
End date YYYY-MM-DD (tweet_search_extractor).
-
#url ⇒ String?
URL substring or domain filter (tweet_search_extractor).
-
#verified_only ⇒ Boolean?
Only verified authors (tweet_search_extractor).
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(tool_type:, advanced_query: nil, any_words: nil, bounding_box: nil, cashtags: nil, conversation_id: nil, exact_phrase: nil, exclude_words: nil, from_user: nil, hashtags: nil, in_reply_to_tweet_id: nil, language: nil, list_id: nil, media_type: nil, mentioning: nil, min_faves: nil, min_quotes: nil, min_replies: nil, min_retweets: nil, place: nil, place_country: nil, point_radius: nil, quotes: nil, quotes_of_tweet_id: nil, replies: nil, results_limit: nil, retweets: nil, retweets_of_tweet_id: nil, search_query: nil, since_date: nil, target_community_id: nil, target_list_id: nil, target_space_id: nil, target_tweet_id: nil, target_username: nil, to_user: nil, until_date: nil, url: nil, verified_only: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see ExtractionRunParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(tool_type:, advanced_query: nil, any_words: nil, bounding_box: nil, cashtags: nil, conversation_id: nil, exact_phrase: nil, exclude_words: nil, from_user: nil, hashtags: nil, in_reply_to_tweet_id: nil, language: nil, list_id: nil, media_type: nil, mentioning: nil, min_faves: nil, min_quotes: nil, min_replies: nil, min_retweets: nil, place: nil, place_country: nil, point_radius: nil, quotes: nil, quotes_of_tweet_id: nil, replies: nil, results_limit: nil, retweets: nil, retweets_of_tweet_id: nil, search_query: nil, since_date: nil, target_community_id: nil, target_list_id: nil, target_space_id: nil, target_tweet_id: nil, target_username: nil, to_user: nil, until_date: nil, url: nil, verified_only: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see XTwitterScraper::Models::ExtractionRunParams for more details.
|
|
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 246
|
Instance Attribute Details
#advanced_query ⇒ String?
Raw advanced search query appended as-is (tweet_search_extractor)
20 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 20 optional :advanced_query, String, api_name: :advancedQuery |
#any_words ⇒ String?
Words or quoted phrases where any one can match. Separate with spaces, commas, or lines. (tweet_search_extractor)
27 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 27 optional :any_words, String, api_name: :anyWords |
#bounding_box ⇒ String?
Geo bounding box, e.g. -74.1 40.6 -73.9 40.8 (tweet_search_extractor)
33 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 33 optional :bounding_box, String, api_name: :boundingBox |
#cashtags ⇒ String?
Cashtags separated by spaces, commas, or lines. (tweet_search_extractor)
39 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 39 optional :cashtags, String |
#conversation_id ⇒ String?
Conversation ID filter (tweet_search_extractor)
45 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 45 optional :conversation_id, String, api_name: :conversationId |
#exact_phrase ⇒ String?
Exact phrase to match (tweet_search_extractor)
51 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 51 optional :exact_phrase, String, api_name: :exactPhrase |
#exclude_words ⇒ String?
Words or quoted phrases to exclude. Separate with spaces, commas, or lines. (tweet_search_extractor)
58 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 58 optional :exclude_words, String, api_name: :excludeWords |
#from_user ⇒ String?
Filter by author username (tweet_search_extractor)
64 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 64 optional :from_user, String, api_name: :fromUser |
#hashtags ⇒ String?
Hashtags separated by spaces, commas, or lines. (tweet_search_extractor)
70 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 70 optional :hashtags, String |
#in_reply_to_tweet_id ⇒ String?
Only replies to this tweet ID (tweet_search_extractor)
76 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 76 optional :in_reply_to_tweet_id, String, api_name: :inReplyToTweetId |
#language ⇒ String?
Language code filter (tweet_search_extractor)
82 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 82 optional :language, String |
#list_id ⇒ String?
Search within a list ID (tweet_search_extractor)
88 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 88 optional :list_id, String, api_name: :listId |
#media_type ⇒ Symbol, ...
Media type filter (tweet_search_extractor)
94 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 94 optional :media_type, enum: -> { XTwitterScraper::ExtractionRunParams::MediaType }, api_name: :mediaType |
#mentioning ⇒ String?
Filter tweets mentioning a username (tweet_search_extractor)
100 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 100 optional :mentioning, String |
#min_faves ⇒ Integer?
Minimum likes threshold (tweet_search_extractor)
106 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 106 optional :min_faves, Integer, api_name: :minFaves |
#min_quotes ⇒ Integer?
Minimum quote count threshold (tweet_search_extractor)
112 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 112 optional :min_quotes, Integer, api_name: :minQuotes |
#min_replies ⇒ Integer?
Minimum replies threshold (tweet_search_extractor)
118 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 118 optional :min_replies, Integer, api_name: :minReplies |
#min_retweets ⇒ Integer?
Minimum retweets threshold (tweet_search_extractor)
124 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 124 optional :min_retweets, Integer, api_name: :minRetweets |
#place ⇒ String?
Search within a place ID (tweet_search_extractor)
130 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 130 optional :place, String |
#place_country ⇒ String?
Search within a country code (tweet_search_extractor)
136 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 136 optional :place_country, String, api_name: :placeCountry |
#point_radius ⇒ String?
Geo point radius, e.g. -73.99 40.73 25mi (tweet_search_extractor)
142 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 142 optional :point_radius, String, api_name: :pointRadius |
#quotes ⇒ Symbol, ...
Quote mode (tweet_search_extractor)
148 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 148 optional :quotes, enum: -> { XTwitterScraper::ExtractionRunParams::Quotes } |
#quotes_of_tweet_id ⇒ String?
Only quotes of this tweet ID (tweet_search_extractor)
154 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 154 optional :quotes_of_tweet_id, String, api_name: :quotesOfTweetId |
#replies ⇒ Symbol, ...
Reply mode (tweet_search_extractor)
160 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 160 optional :replies, enum: -> { XTwitterScraper::ExtractionRunParams::Replies } |
#results_limit ⇒ Integer?
Maximum number of results to extract. When set, the extraction stops after reaching this limit.
167 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 167 optional :results_limit, Integer, api_name: :resultsLimit |
#retweets ⇒ Symbol, ...
Retweet mode (tweet_search_extractor)
173 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 173 optional :retweets, enum: -> { XTwitterScraper::ExtractionRunParams::Retweets } |
#retweets_of_tweet_id ⇒ String?
Only retweets of this tweet ID (tweet_search_extractor)
179 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 179 optional :retweets_of_tweet_id, String, api_name: :retweetsOfTweetId |
#search_query ⇒ String?
Required for tweet_search_extractor & community_search.
185 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 185 optional :search_query, String, api_name: :searchQuery |
#since_date ⇒ Date?
Start date YYYY-MM-DD (tweet_search_extractor)
191 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 191 optional :since_date, Date, api_name: :sinceDate |
#target_community_id ⇒ String?
Required for community_post_extractor & community_search.
197 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 197 optional :target_community_id, String, api_name: :targetCommunityId |
#target_list_id ⇒ String?
Required for list_follower_explorer, list_member_extractor & list_post_extractor.
204 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 204 optional :target_list_id, String, api_name: :targetListId |
#target_space_id ⇒ String?
Required for space_explorer.
210 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 210 optional :target_space_id, String, api_name: :targetSpaceId |
#target_tweet_id ⇒ String?
215 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 215 optional :target_tweet_id, String, api_name: :targetTweetId |
#target_username ⇒ String?
220 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 220 optional :target_username, String, api_name: :targetUsername |
#to_user ⇒ String?
Filter replies sent to a username (tweet_search_extractor)
226 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 226 optional :to_user, String, api_name: :toUser |
#tool_type ⇒ Symbol, XTwitterScraper::Models::ExtractionRunParams::ToolType
Identifier for the extraction tool used to run a job.
14 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 14 required :tool_type, enum: -> { XTwitterScraper::ExtractionRunParams::ToolType }, api_name: :toolType |
#until_date ⇒ Date?
End date YYYY-MM-DD (tweet_search_extractor)
232 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 232 optional :until_date, Date, api_name: :untilDate |
#url ⇒ String?
URL substring or domain filter (tweet_search_extractor)
238 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 238 optional :url, String |
#verified_only ⇒ Boolean?
Only verified authors (tweet_search_extractor)
244 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 244 optional :verified_only, XTwitterScraper::Internal::Type::Boolean, api_name: :verifiedOnly |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 358
|
Instance Method Details
#to_hash ⇒ {
256 |
# File 'sig/x_twitter_scraper/models/extraction_run_params.rbs', line 256
def to_hash: -> {
|