Class: XTwitterScraper::Models::ExtractionRunParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- XTwitterScraper::Models::ExtractionRunParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/x_twitter_scraper/models/extraction_run_params.rb
Overview
Defined Under Namespace
Modules: ToolType
Instance Attribute Summary collapse
-
#advanced_query ⇒ String?
Raw advanced search query appended as-is (tweet_search_extractor).
-
#exact_phrase ⇒ String?
Exact phrase to match (tweet_search_extractor).
-
#exclude_words ⇒ String?
Words to exclude from results (tweet_search_extractor).
- #search_query ⇒ String?
- #target_community_id ⇒ String?
- #target_list_id ⇒ String?
- #target_space_id ⇒ String?
- #target_tweet_id ⇒ String?
- #target_username ⇒ String?
-
#tool_type ⇒ Symbol, XTwitterScraper::Models::ExtractionRunParams::ToolType
Identifier for the extraction tool used to run a job.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(tool_type:, advanced_query: nil, exact_phrase: nil, exclude_words: nil, search_query: nil, target_community_id: nil, target_list_id: nil, target_space_id: nil, target_tweet_id: nil, target_username: nil, request_options: {}) ⇒ Object
|
|
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 64
|
Instance Attribute Details
#advanced_query ⇒ String?
Raw advanced search query appended as-is (tweet_search_extractor)
20 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 20 optional :advanced_query, String, api_name: :advancedQuery |
#exact_phrase ⇒ String?
Exact phrase to match (tweet_search_extractor)
26 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 26 optional :exact_phrase, String, api_name: :exactPhrase |
#exclude_words ⇒ String?
Words to exclude from results (tweet_search_extractor)
32 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 32 optional :exclude_words, String, api_name: :excludeWords |
#search_query ⇒ String?
37 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 37 optional :search_query, String, api_name: :searchQuery |
#target_community_id ⇒ String?
42 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 42 optional :target_community_id, String, api_name: :targetCommunityId |
#target_list_id ⇒ String?
47 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 47 optional :target_list_id, String, api_name: :targetListId |
#target_space_id ⇒ String?
52 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 52 optional :target_space_id, String, api_name: :targetSpaceId |
#target_tweet_id ⇒ String?
57 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 57 optional :target_tweet_id, String, api_name: :targetTweetId |
#target_username ⇒ String?
62 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 62 optional :target_username, String, api_name: :targetUsername |
#tool_type ⇒ Symbol, XTwitterScraper::Models::ExtractionRunParams::ToolType
Identifier for the extraction tool used to run a job.
14 |
# File 'lib/x_twitter_scraper/models/extraction_run_params.rb', line 14 required :tool_type, enum: -> { XTwitterScraper::ExtractionRunParams::ToolType }, api_name: :toolType |