Class: XTwitterScraper::Models::Support::TicketRetrieveResponse::Message::Attachment
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- XTwitterScraper::Models::Support::TicketRetrieveResponse::Message::Attachment
- Defined in:
- lib/x_twitter_scraper/models/support/ticket_retrieve_response.rb,
sig/x_twitter_scraper/models/support/ticket_retrieve_response.rbs
Defined Under Namespace
Modules: ContentType, Kind, Status
Instance Attribute Summary collapse
-
#content_type ⇒ Symbol, XTwitterScraper::Models::Support::TicketRetrieveResponse::Message::Attachment::ContentType
Validated media type.
- #filename ⇒ String
-
#kind ⇒ Symbol, XTwitterScraper::Models::Support::TicketRetrieveResponse::Message::Attachment::Kind
Attachment media class.
- #public_id ⇒ String
- #size_bytes ⇒ Integer
-
#status ⇒ Symbol, XTwitterScraper::Models::Support::TicketRetrieveResponse::Message::Attachment::Status
Storage processing state.
- #url ⇒ String
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(content_type:, filename:, kind:, public_id:, size_bytes:, status:, url:) ⇒ Object
constructor
Downloadable image or video attached to a support message.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(content_type:, filename:, kind:, public_id:, size_bytes:, status:, url:) ⇒ Object
Downloadable image or video attached to a support message.
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 |
# File 'lib/x_twitter_scraper/models/support/ticket_retrieve_response.rb', line 79 class Attachment < XTwitterScraper::Internal::Type::BaseModel # @!attribute content_type # Validated media type. # # @return [Symbol, XTwitterScraper::Models::Support::TicketRetrieveResponse::Message::Attachment::ContentType] required :content_type, enum: -> { XTwitterScraper::Models::Support::TicketRetrieveResponse::Message::Attachment::ContentType }, api_name: :contentType # @!attribute filename # # @return [String] required :filename, String # @!attribute kind # Attachment media class. # # @return [Symbol, XTwitterScraper::Models::Support::TicketRetrieveResponse::Message::Attachment::Kind] required :kind, enum: -> { XTwitterScraper::Models::Support::TicketRetrieveResponse::Message::Attachment::Kind } # @!attribute public_id # # @return [String] required :public_id, String, api_name: :publicId # @!attribute size_bytes # # @return [Integer] required :size_bytes, Integer, api_name: :sizeBytes # @!attribute status # Storage processing state. # # @return [Symbol, XTwitterScraper::Models::Support::TicketRetrieveResponse::Message::Attachment::Status] required :status, enum: -> { XTwitterScraper::Models::Support::TicketRetrieveResponse::Message::Attachment::Status } # @!attribute url # # @return [String] required :url, String # @!method initialize(content_type:, filename:, kind:, public_id:, size_bytes:, status:, url:) # Downloadable image or video attached to a support message. # # @param content_type [Symbol, XTwitterScraper::Models::Support::TicketRetrieveResponse::Message::Attachment::ContentType] Validated media type. # # @param filename [String] # # @param kind [Symbol, XTwitterScraper::Models::Support::TicketRetrieveResponse::Message::Attachment::Kind] Attachment media class. # # @param public_id [String] # # @param size_bytes [Integer] # # @param status [Symbol, XTwitterScraper::Models::Support::TicketRetrieveResponse::Message::Attachment::Status] Storage processing state. # # @param url [String] # Validated media type. # # @see XTwitterScraper::Models::Support::TicketRetrieveResponse::Message::Attachment#content_type module ContentType extend XTwitterScraper::Internal::Type::Enum IMAGE_JPEG = :"image/jpeg" IMAGE_PNG = :"image/png" IMAGE_GIF = :"image/gif" IMAGE_WEBP = :"image/webp" VIDEO_MP4 = :"video/mp4" VIDEO_QUICKTIME = :"video/quicktime" VIDEO_WEBM = :"video/webm" # @!method self.values # @return [Array<Symbol>] end # Attachment media class. # # @see XTwitterScraper::Models::Support::TicketRetrieveResponse::Message::Attachment#kind module Kind extend XTwitterScraper::Internal::Type::Enum IMAGE = :image VIDEO = :video # @!method self.values # @return [Array<Symbol>] end # Storage processing state. # # @see XTwitterScraper::Models::Support::TicketRetrieveResponse::Message::Attachment#status module Status extend XTwitterScraper::Internal::Type::Enum PENDING = :pending READY = :ready FAILED = :failed # @!method self.values # @return [Array<Symbol>] end end |
Instance Attribute Details
#content_type ⇒ Symbol, XTwitterScraper::Models::Support::TicketRetrieveResponse::Message::Attachment::ContentType
Validated media type.
84 85 86 |
# File 'lib/x_twitter_scraper/models/support/ticket_retrieve_response.rb', line 84 required :content_type, enum: -> { XTwitterScraper::Models::Support::TicketRetrieveResponse::Message::Attachment::ContentType }, api_name: :contentType |
#filename ⇒ String
91 |
# File 'lib/x_twitter_scraper/models/support/ticket_retrieve_response.rb', line 91 required :filename, String |
#kind ⇒ Symbol, XTwitterScraper::Models::Support::TicketRetrieveResponse::Message::Attachment::Kind
Attachment media class.
97 98 |
# File 'lib/x_twitter_scraper/models/support/ticket_retrieve_response.rb', line 97 required :kind, enum: -> { XTwitterScraper::Models::Support::TicketRetrieveResponse::Message::Attachment::Kind } |
#public_id ⇒ String
103 |
# File 'lib/x_twitter_scraper/models/support/ticket_retrieve_response.rb', line 103 required :public_id, String, api_name: :publicId |
#size_bytes ⇒ Integer
108 |
# File 'lib/x_twitter_scraper/models/support/ticket_retrieve_response.rb', line 108 required :size_bytes, Integer, api_name: :sizeBytes |
#status ⇒ Symbol, XTwitterScraper::Models::Support::TicketRetrieveResponse::Message::Attachment::Status
Storage processing state.
114 115 |
# File 'lib/x_twitter_scraper/models/support/ticket_retrieve_response.rb', line 114 required :status, enum: -> { XTwitterScraper::Models::Support::TicketRetrieveResponse::Message::Attachment::Status } |
#url ⇒ String
120 |
# File 'lib/x_twitter_scraper/models/support/ticket_retrieve_response.rb', line 120 required :url, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/x_twitter_scraper/models/support/ticket_retrieve_response.rb', line 153
|
Instance Method Details
#to_hash ⇒ {
140 |
# File 'sig/x_twitter_scraper/models/support/ticket_retrieve_response.rbs', line 140
def to_hash: -> {
|