Class: XTwitterScraper::Models::UserProfile
Instance Attribute Summary collapse
Instance Method Summary
collapse
-
#initialize(id:, name:, username:, automated_by: nil, can_dm: nil, community_role: nil, cover_picture: nil, created_at: nil, description: nil, favourites_count: nil, followers: nil, following: nil, has_custom_timelines: nil, is_automated: nil, is_blue_verified: nil, is_translator: nil, is_verified: nil, location: nil, media_count: nil, pinned_tweet_ids: nil, possibly_sensitive: nil, profile_bio: nil, profile_banner_url: nil, profile_picture: nil, protected: nil, statuses_count: nil, unavailable: nil, unavailable_reason: nil, url: nil, verified: nil, verified_type: nil, viewer_followed_by: nil, viewer_following: nil, withheld_in_countries: nil) ⇒ Object
constructor
X user profile with bio, follower counts, and verification status.
-
#to_hash ⇒ {
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, name:, username:, automated_by: nil, can_dm: nil, community_role: nil, cover_picture: nil, created_at: nil, description: nil, favourites_count: nil, followers: nil, following: nil, has_custom_timelines: nil, is_automated: nil, is_blue_verified: nil, is_translator: nil, is_verified: nil, location: nil, media_count: nil, pinned_tweet_ids: nil, possibly_sensitive: nil, profile_bio: nil, profile_banner_url: nil, profile_picture: nil, protected: nil, statuses_count: nil, unavailable: nil, unavailable_reason: nil, url: nil, verified: nil, verified_type: nil, viewer_followed_by: nil, viewer_following: nil, withheld_in_countries: nil) ⇒ Object
X user profile with bio, follower counts, and verification status.
|
# File 'lib/x_twitter_scraper/models/user_profile.rb', line 186
|
Instance Attribute Details
#automated_by ⇒ String?
24
|
# File 'lib/x_twitter_scraper/models/user_profile.rb', line 24
optional :automated_by, String, api_name: :automatedBy
|
#can_dm ⇒ Boolean?
29
|
# File 'lib/x_twitter_scraper/models/user_profile.rb', line 29
optional :can_dm, XTwitterScraper::Internal::Type::Boolean, api_name: :canDm
|
Community role when returned by community member reads
35
|
# File 'lib/x_twitter_scraper/models/user_profile.rb', line 35
optional :community_role, String, api_name: :communityRole
|
#cover_picture ⇒ String?
40
|
# File 'lib/x_twitter_scraper/models/user_profile.rb', line 40
optional :cover_picture, String, api_name: :coverPicture
|
#created_at ⇒ String?
45
|
# File 'lib/x_twitter_scraper/models/user_profile.rb', line 45
optional :created_at, String, api_name: :createdAt
|
#description ⇒ String?
50
|
# File 'lib/x_twitter_scraper/models/user_profile.rb', line 50
optional :description, String
|
#favourites_count ⇒ Integer?
55
|
# File 'lib/x_twitter_scraper/models/user_profile.rb', line 55
optional :favourites_count, Integer, api_name: :favouritesCount
|
#followers ⇒ Integer?
60
|
# File 'lib/x_twitter_scraper/models/user_profile.rb', line 60
optional :followers, Integer
|
#following ⇒ Integer?
65
|
# File 'lib/x_twitter_scraper/models/user_profile.rb', line 65
optional :following, Integer
|
#has_custom_timelines ⇒ Boolean?
70
|
# File 'lib/x_twitter_scraper/models/user_profile.rb', line 70
optional :has_custom_timelines, XTwitterScraper::Internal::Type::Boolean, api_name: :hasCustomTimelines
|
#id ⇒ String
9
|
# File 'lib/x_twitter_scraper/models/user_profile.rb', line 9
required :id, String
|
#is_automated ⇒ Boolean?
75
|
# File 'lib/x_twitter_scraper/models/user_profile.rb', line 75
optional :is_automated, XTwitterScraper::Internal::Type::Boolean, api_name: :isAutomated
|
#is_blue_verified ⇒ Boolean?
Whether X shows a blue verification badge
81
|
# File 'lib/x_twitter_scraper/models/user_profile.rb', line 81
optional :is_blue_verified, XTwitterScraper::Internal::Type::Boolean, api_name: :isBlueVerified
|
#is_translator ⇒ Boolean?
86
|
# File 'lib/x_twitter_scraper/models/user_profile.rb', line 86
optional :is_translator, XTwitterScraper::Internal::Type::Boolean, api_name: :isTranslator
|
#is_verified ⇒ Boolean?
Whether X marks the profile as verified
92
|
# File 'lib/x_twitter_scraper/models/user_profile.rb', line 92
optional :is_verified, XTwitterScraper::Internal::Type::Boolean, api_name: :isVerified
|
#location ⇒ String?
97
|
# File 'lib/x_twitter_scraper/models/user_profile.rb', line 97
optional :location, String
|
102
|
# File 'lib/x_twitter_scraper/models/user_profile.rb', line 102
optional :media_count, Integer, api_name: :mediaCount
|
#name ⇒ String
14
|
# File 'lib/x_twitter_scraper/models/user_profile.rb', line 14
required :name, String
|
107
|
# File 'lib/x_twitter_scraper/models/user_profile.rb', line 107
optional :pinned_tweet_ids, XTwitterScraper::Internal::Type::ArrayOf[String], api_name: :pinnedTweetIds
|
#possibly_sensitive ⇒ Boolean?
112
|
# File 'lib/x_twitter_scraper/models/user_profile.rb', line 112
optional :possibly_sensitive, XTwitterScraper::Internal::Type::Boolean, api_name: :possiblySensitive
|
#profile_banner_url ⇒ String?
Original X profile banner field when available
124
|
# File 'lib/x_twitter_scraper/models/user_profile.rb', line 124
optional :profile_banner_url, String, api_name: :profileBannerUrl
|
#profile_bio ⇒ Hash{Symbol=>Object}?
Structured profile bio with entity annotations
118
|
# File 'lib/x_twitter_scraper/models/user_profile.rb', line 118
optional :profile_bio, XTwitterScraper::Internal::Type::HashOf[XTwitterScraper::Internal::Type::Unknown]
|
#profile_picture ⇒ String?
129
|
# File 'lib/x_twitter_scraper/models/user_profile.rb', line 129
optional :profile_picture, String, api_name: :profilePicture
|
#protected ⇒ Boolean?
Whether the profile protects its posts
135
|
# File 'lib/x_twitter_scraper/models/user_profile.rb', line 135
optional :protected, XTwitterScraper::Internal::Type::Boolean
|
#statuses_count ⇒ Integer?
140
|
# File 'lib/x_twitter_scraper/models/user_profile.rb', line 140
optional :statuses_count, Integer, api_name: :statusesCount
|
#unavailable ⇒ Boolean?
145
|
# File 'lib/x_twitter_scraper/models/user_profile.rb', line 145
optional :unavailable, XTwitterScraper::Internal::Type::Boolean
|
#unavailable_reason ⇒ String?
150
|
# File 'lib/x_twitter_scraper/models/user_profile.rb', line 150
optional :unavailable_reason, String, api_name: :unavailableReason
|
#url ⇒ String?
155
|
# File 'lib/x_twitter_scraper/models/user_profile.rb', line 155
optional :url, String
|
#username ⇒ String
19
|
# File 'lib/x_twitter_scraper/models/user_profile.rb', line 19
required :username, String
|
#verified ⇒ Boolean?
160
|
# File 'lib/x_twitter_scraper/models/user_profile.rb', line 160
optional :verified, XTwitterScraper::Internal::Type::Boolean
|
#verified_type ⇒ String?
165
|
# File 'lib/x_twitter_scraper/models/user_profile.rb', line 165
optional :verified_type, String, api_name: :verifiedType
|
#viewer_followed_by ⇒ Boolean?
Whether this profile follows the authenticated viewer
171
|
# File 'lib/x_twitter_scraper/models/user_profile.rb', line 171
optional :viewer_followed_by, XTwitterScraper::Internal::Type::Boolean, api_name: :viewerFollowedBy
|
#viewer_following ⇒ Boolean?
Whether the authenticated viewer follows this profile
177
|
# File 'lib/x_twitter_scraper/models/user_profile.rb', line 177
optional :viewer_following, XTwitterScraper::Internal::Type::Boolean, api_name: :viewerFollowing
|
#withheld_in_countries ⇒ Array<String>?
182
183
184
|
# File 'lib/x_twitter_scraper/models/user_profile.rb', line 182
optional :withheld_in_countries,
XTwitterScraper::Internal::Type::ArrayOf[String],
api_name: :withheldInCountries
|
Instance Method Details
#to_hash ⇒ {
209
|
# File 'sig/x_twitter_scraper/models/user_profile.rbs', line 209
def to_hash: -> {
|