Class: XTwitterScraper::Models::X::TweetDetail
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- XTwitterScraper::Models::X::TweetDetail
- Defined in:
- lib/x_twitter_scraper/models/x/tweet_detail.rb
Defined Under Namespace
Classes: Media
Instance Attribute Summary collapse
- #bookmark_count ⇒ Integer
-
#conversation_id ⇒ String?
ID of the root tweet in the conversation thread.
- #created_at ⇒ String?
-
#entities ⇒ Hash{Symbol=>Object}?
Parsed entities from the tweet text (URLs, mentions, hashtags, media).
- #id ⇒ String
-
#is_note_tweet ⇒ Boolean?
Whether this is a Note Tweet (long-form post, up to 25,000 characters).
-
#is_quote_status ⇒ Boolean?
Whether this tweet quotes another tweet.
-
#is_reply ⇒ Boolean?
Whether this tweet is a reply to another tweet.
- #like_count ⇒ Integer
-
#media ⇒ Array<XTwitterScraper::Models::X::TweetDetail::Media>?
Attached media items, omitted when the tweet has no media.
- #quote_count ⇒ Integer
-
#quoted_tweet ⇒ Hash{Symbol=>Object}?
The quoted tweet object, present when isQuoteStatus is true.
- #reply_count ⇒ Integer
- #retweet_count ⇒ Integer
-
#source ⇒ String?
Client application used to post this tweet.
- #text ⇒ String
- #view_count ⇒ Integer
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from XTwitterScraper::Internal::Type::BaseModel
Instance Attribute Details
#bookmark_count ⇒ Integer
15 |
# File 'lib/x_twitter_scraper/models/x/tweet_detail.rb', line 15 required :bookmark_count, Integer, api_name: :bookmarkCount |
#conversation_id ⇒ String?
ID of the root tweet in the conversation thread
51 |
# File 'lib/x_twitter_scraper/models/x/tweet_detail.rb', line 51 optional :conversation_id, String, api_name: :conversationId |
#created_at ⇒ String?
56 |
# File 'lib/x_twitter_scraper/models/x/tweet_detail.rb', line 56 optional :created_at, String, api_name: :createdAt |
#entities ⇒ Hash{Symbol=>Object}?
Parsed entities from the tweet text (URLs, mentions, hashtags, media)
62 |
# File 'lib/x_twitter_scraper/models/x/tweet_detail.rb', line 62 optional :entities, XTwitterScraper::Internal::Type::HashOf[XTwitterScraper::Internal::Type::Unknown] |
#id ⇒ String
10 |
# File 'lib/x_twitter_scraper/models/x/tweet_detail.rb', line 10 required :id, String |
#is_note_tweet ⇒ Boolean?
Whether this is a Note Tweet (long-form post, up to 25,000 characters)
68 |
# File 'lib/x_twitter_scraper/models/x/tweet_detail.rb', line 68 optional :is_note_tweet, XTwitterScraper::Internal::Type::Boolean, api_name: :isNoteTweet |
#is_quote_status ⇒ Boolean?
Whether this tweet quotes another tweet
74 |
# File 'lib/x_twitter_scraper/models/x/tweet_detail.rb', line 74 optional :is_quote_status, XTwitterScraper::Internal::Type::Boolean, api_name: :isQuoteStatus |
#is_reply ⇒ Boolean?
Whether this tweet is a reply to another tweet
80 |
# File 'lib/x_twitter_scraper/models/x/tweet_detail.rb', line 80 optional :is_reply, XTwitterScraper::Internal::Type::Boolean, api_name: :isReply |
#like_count ⇒ Integer
20 |
# File 'lib/x_twitter_scraper/models/x/tweet_detail.rb', line 20 required :like_count, Integer, api_name: :likeCount |
#media ⇒ Array<XTwitterScraper::Models::X::TweetDetail::Media>?
Attached media items, omitted when the tweet has no media
86 |
# File 'lib/x_twitter_scraper/models/x/tweet_detail.rb', line 86 optional :media, -> { XTwitterScraper::Internal::Type::ArrayOf[XTwitterScraper::X::TweetDetail::Media] } |
#quote_count ⇒ Integer
25 |
# File 'lib/x_twitter_scraper/models/x/tweet_detail.rb', line 25 required :quote_count, Integer, api_name: :quoteCount |
#quoted_tweet ⇒ Hash{Symbol=>Object}?
The quoted tweet object, present when isQuoteStatus is true
92 |
# File 'lib/x_twitter_scraper/models/x/tweet_detail.rb', line 92 optional :quoted_tweet, XTwitterScraper::Internal::Type::HashOf[XTwitterScraper::Internal::Type::Unknown] |
#reply_count ⇒ Integer
30 |
# File 'lib/x_twitter_scraper/models/x/tweet_detail.rb', line 30 required :reply_count, Integer, api_name: :replyCount |
#retweet_count ⇒ Integer
35 |
# File 'lib/x_twitter_scraper/models/x/tweet_detail.rb', line 35 required :retweet_count, Integer, api_name: :retweetCount |
#source ⇒ String?
Client application used to post this tweet
98 |
# File 'lib/x_twitter_scraper/models/x/tweet_detail.rb', line 98 optional :source, String |
#text ⇒ String
40 |
# File 'lib/x_twitter_scraper/models/x/tweet_detail.rb', line 40 required :text, String |
#view_count ⇒ Integer
45 |
# File 'lib/x_twitter_scraper/models/x/tweet_detail.rb', line 45 required :view_count, Integer, api_name: :viewCount |