Class: XTwitterScraper::Models::X::TweetRetrieveResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- XTwitterScraper::Models::X::TweetRetrieveResponse
- Defined in:
- lib/x_twitter_scraper/models/x/tweet_retrieve_response.rb
Overview
Instance Attribute Summary collapse
-
#author ⇒ XTwitterScraper::Models::X::TweetAuthor?
Author of a tweet with follower count and verification status.
-
#tweet ⇒ XTwitterScraper::Models::X::TweetDetail
Full tweet with text, engagement metrics, media, and metadata.
Instance Method Summary collapse
- #initialize(tweet:, author: nil) ⇒ Object constructor
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(tweet:, author: nil) ⇒ Object
|
|
# File 'lib/x_twitter_scraper/models/x/tweet_retrieve_response.rb', line 20
|
Instance Attribute Details
#author ⇒ XTwitterScraper::Models::X::TweetAuthor?
Author of a tweet with follower count and verification status.
18 |
# File 'lib/x_twitter_scraper/models/x/tweet_retrieve_response.rb', line 18 optional :author, -> { XTwitterScraper::X::TweetAuthor } |
#tweet ⇒ XTwitterScraper::Models::X::TweetDetail
Full tweet with text, engagement metrics, media, and metadata.
12 |
# File 'lib/x_twitter_scraper/models/x/tweet_retrieve_response.rb', line 12 required :tweet, -> { XTwitterScraper::X::TweetDetail } |