Class: XTwitterScraper::Models::X::UserRetrieveTweetsParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- XTwitterScraper::Models::X::UserRetrieveTweetsParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/x_twitter_scraper/models/x/user_retrieve_tweets_params.rb,
sig/x_twitter_scraper/models/x/user_retrieve_tweets_params.rbs
Overview
Defined Under Namespace
Modules: MediaType, Quotes, Replies, Retweets
Constant Summary
Constants included from Internal::Type::RequestParameters
Internal::Type::RequestParameters::XTwitterScraper
Instance Attribute Summary collapse
-
#any_words ⇒ String?
Words or quoted phrases where any one can match.
-
#blue_verified_only ⇒ Boolean?
Only return tweets from Blue-verified authors.
-
#card_name ⇒ String?
Match the Tweet card name.
-
#cashtags ⇒ String?
Cashtags separated by spaces, commas, or lines.
-
#conversation_id ⇒ String?
Conversation ID filter.
-
#cursor ⇒ String?
Cursor from the previous response.
-
#exact_phrase ⇒ String?
Exact phrase to match.
-
#exclude_source ⇒ String?
Exclude a source application.
-
#exclude_words ⇒ String?
Words or quoted phrases to exclude.
-
#from_user ⇒ String?
Filter by author username.
-
#geocode ⇒ String?
Match latitude, longitude, and radius.
-
#hashtags ⇒ String?
Hashtags separated by spaces, commas, or lines.
- #id ⇒ String
-
#in_reply_to_tweet_id ⇒ String?
Only replies to this tweet ID.
-
#include_parent_tweet ⇒ Boolean?
Include parent tweet for replies.
-
#include_replies ⇒ Boolean?
Include reply tweets.
-
#language ⇒ String?
Language code filter, e.g.
-
#max_faves ⇒ Integer?
Maximum likes threshold.
-
#max_id ⇒ String?
Return Tweets older than this Tweet ID.
-
#max_quotes ⇒ Integer?
Maximum quotes threshold.
-
#max_replies ⇒ Integer?
Maximum replies threshold.
-
#max_retweets ⇒ Integer?
Maximum retweets threshold.
-
#media_type ⇒ Symbol, ...
Filter by media type.
-
#mentioning ⇒ String?
Filter tweets mentioning a username.
-
#min_bookmarks ⇒ Integer?
Minimum bookmark count threshold.
-
#min_faves ⇒ Integer?
Minimum likes threshold.
-
#min_quotes ⇒ Integer?
Minimum quote count threshold.
-
#min_replies ⇒ Integer?
Minimum replies threshold.
-
#min_retweets ⇒ Integer?
Minimum retweets threshold.
-
#min_views ⇒ Integer?
Minimum view count threshold.
-
#native_retweets ⇒ Boolean?
Only return native reposts.
-
#near ⇒ String?
Match a place name.
-
#news ⇒ Boolean?
Only return news results.
-
#page_size ⇒ Integer?
Automatic pages accept 1-300 Tweets.
-
#quotes ⇒ Symbol, ...
Quote mode.
-
#quotes_of_tweet_id ⇒ String?
Only quotes of this tweet ID.
-
#replies ⇒ Symbol, ...
Reply mode.
-
#retweets ⇒ Symbol, ...
Retweet mode.
-
#retweets_of_tweet_id ⇒ String?
Only retweets of this tweet ID.
-
#safe ⇒ Boolean?
Enable the safe-search filter.
-
#since_date ⇒ Date?
Start date in YYYY-MM-DD format.
-
#since_id ⇒ String?
Return Tweets newer than this Tweet ID.
-
#source ⇒ String?
Match the source application.
-
#to_user ⇒ String?
Filter replies sent to a username.
-
#until_date ⇒ Date?
End date in YYYY-MM-DD format.
-
#url ⇒ String?
URL substring or domain filter.
-
#verified_only ⇒ Boolean?
Only return tweets from verified authors.
-
#within ⇒ String?
Set the radius for the near filter.
-
#within_time ⇒ String?
Match Tweets inside a recent time window.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:, any_words: nil, blue_verified_only: nil, card_name: nil, cashtags: nil, conversation_id: nil, cursor: nil, exact_phrase: nil, exclude_source: nil, exclude_words: nil, from_user: nil, geocode: nil, hashtags: nil, include_parent_tweet: nil, include_replies: nil, in_reply_to_tweet_id: nil, language: nil, max_faves: nil, max_id: nil, max_quotes: nil, max_replies: nil, max_retweets: nil, media_type: nil, mentioning: nil, min_bookmarks: nil, min_faves: nil, min_quotes: nil, min_replies: nil, min_retweets: nil, min_views: nil, native_retweets: nil, near: nil, news: nil, page_size: nil, quotes: nil, quotes_of_tweet_id: nil, replies: nil, retweets: nil, retweets_of_tweet_id: nil, safe: nil, since_date: nil, since_id: nil, source: nil, to_user: nil, until_date: nil, url: nil, verified_only: nil, within: nil, within_time: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see UserRetrieveTweetsParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, any_words: nil, blue_verified_only: nil, card_name: nil, cashtags: nil, conversation_id: nil, cursor: nil, exact_phrase: nil, exclude_source: nil, exclude_words: nil, from_user: nil, geocode: nil, hashtags: nil, include_parent_tweet: nil, include_replies: nil, in_reply_to_tweet_id: nil, language: nil, max_faves: nil, max_id: nil, max_quotes: nil, max_replies: nil, max_retweets: nil, media_type: nil, mentioning: nil, min_bookmarks: nil, min_faves: nil, min_quotes: nil, min_replies: nil, min_retweets: nil, min_views: nil, native_retweets: nil, near: nil, news: nil, page_size: nil, quotes: nil, quotes_of_tweet_id: nil, replies: nil, retweets: nil, retweets_of_tweet_id: nil, safe: nil, since_date: nil, since_id: nil, source: nil, to_user: nil, until_date: nil, url: nil, verified_only: nil, within: nil, within_time: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see XTwitterScraper::Models::X::UserRetrieveTweetsParams for more details.
|
|
# File 'lib/x_twitter_scraper/models/x/user_retrieve_tweets_params.rb', line 311
|
Instance Attribute Details
#any_words ⇒ String?
Words or quoted phrases where any one can match. Separate with spaces, commas, or lines.
25 |
# File 'lib/x_twitter_scraper/models/x/user_retrieve_tweets_params.rb', line 25 optional :any_words, String |
#blue_verified_only ⇒ Boolean?
Only return tweets from Blue-verified authors.
31 |
# File 'lib/x_twitter_scraper/models/x/user_retrieve_tweets_params.rb', line 31 optional :blue_verified_only, XTwitterScraper::Internal::Type::Boolean |
#card_name ⇒ String?
Match the Tweet card name.
37 |
# File 'lib/x_twitter_scraper/models/x/user_retrieve_tweets_params.rb', line 37 optional :card_name, String |
#cashtags ⇒ String?
Cashtags separated by spaces, commas, or lines.
43 |
# File 'lib/x_twitter_scraper/models/x/user_retrieve_tweets_params.rb', line 43 optional :cashtags, String |
#conversation_id ⇒ String?
Conversation ID filter.
49 |
# File 'lib/x_twitter_scraper/models/x/user_retrieve_tweets_params.rb', line 49 optional :conversation_id, String |
#cursor ⇒ String?
Cursor from the previous response. Xquik cursors resume automatic coverage. Existing unprefixed cursors keep legacy standard behavior.
56 |
# File 'lib/x_twitter_scraper/models/x/user_retrieve_tweets_params.rb', line 56 optional :cursor, String |
#exact_phrase ⇒ String?
Exact phrase to match.
62 |
# File 'lib/x_twitter_scraper/models/x/user_retrieve_tweets_params.rb', line 62 optional :exact_phrase, String |
#exclude_source ⇒ String?
Exclude a source application.
68 |
# File 'lib/x_twitter_scraper/models/x/user_retrieve_tweets_params.rb', line 68 optional :exclude_source, String |
#exclude_words ⇒ String?
Words or quoted phrases to exclude. Separate with spaces, commas, or lines.
74 |
# File 'lib/x_twitter_scraper/models/x/user_retrieve_tweets_params.rb', line 74 optional :exclude_words, String |
#from_user ⇒ String?
Filter by author username.
80 |
# File 'lib/x_twitter_scraper/models/x/user_retrieve_tweets_params.rb', line 80 optional :from_user, String |
#geocode ⇒ String?
Match latitude, longitude, and radius.
86 |
# File 'lib/x_twitter_scraper/models/x/user_retrieve_tweets_params.rb', line 86 optional :geocode, String |
#hashtags ⇒ String?
Hashtags separated by spaces, commas, or lines.
92 |
# File 'lib/x_twitter_scraper/models/x/user_retrieve_tweets_params.rb', line 92 optional :hashtags, String |
#id ⇒ String
18 |
# File 'lib/x_twitter_scraper/models/x/user_retrieve_tweets_params.rb', line 18 required :id, String |
#in_reply_to_tweet_id ⇒ String?
Only replies to this tweet ID.
110 |
# File 'lib/x_twitter_scraper/models/x/user_retrieve_tweets_params.rb', line 110 optional :in_reply_to_tweet_id, String |
#include_parent_tweet ⇒ Boolean?
Include parent tweet for replies
98 |
# File 'lib/x_twitter_scraper/models/x/user_retrieve_tweets_params.rb', line 98 optional :include_parent_tweet, XTwitterScraper::Internal::Type::Boolean |
#include_replies ⇒ Boolean?
Include reply tweets
104 |
# File 'lib/x_twitter_scraper/models/x/user_retrieve_tweets_params.rb', line 104 optional :include_replies, XTwitterScraper::Internal::Type::Boolean |
#language ⇒ String?
Language code filter, e.g. en or tr.
116 |
# File 'lib/x_twitter_scraper/models/x/user_retrieve_tweets_params.rb', line 116 optional :language, String |
#max_faves ⇒ Integer?
Maximum likes threshold. maxLikes is also accepted.
122 |
# File 'lib/x_twitter_scraper/models/x/user_retrieve_tweets_params.rb', line 122 optional :max_faves, Integer |
#max_id ⇒ String?
Return Tweets older than this Tweet ID.
128 |
# File 'lib/x_twitter_scraper/models/x/user_retrieve_tweets_params.rb', line 128 optional :max_id, String |
#max_quotes ⇒ Integer?
Maximum quotes threshold.
134 |
# File 'lib/x_twitter_scraper/models/x/user_retrieve_tweets_params.rb', line 134 optional :max_quotes, Integer |
#max_replies ⇒ Integer?
Maximum replies threshold.
140 |
# File 'lib/x_twitter_scraper/models/x/user_retrieve_tweets_params.rb', line 140 optional :max_replies, Integer |
#max_retweets ⇒ Integer?
Maximum retweets threshold.
146 |
# File 'lib/x_twitter_scraper/models/x/user_retrieve_tweets_params.rb', line 146 optional :max_retweets, Integer |
#media_type ⇒ Symbol, ...
Filter by media type.
152 |
# File 'lib/x_twitter_scraper/models/x/user_retrieve_tweets_params.rb', line 152 optional :media_type, enum: -> { XTwitterScraper::X::UserRetrieveTweetsParams::MediaType } |
#mentioning ⇒ String?
Filter tweets mentioning a username.
158 |
# File 'lib/x_twitter_scraper/models/x/user_retrieve_tweets_params.rb', line 158 optional :mentioning, String |
#min_bookmarks ⇒ Integer?
Minimum bookmark count threshold.
164 |
# File 'lib/x_twitter_scraper/models/x/user_retrieve_tweets_params.rb', line 164 optional :min_bookmarks, Integer |
#min_faves ⇒ Integer?
Minimum likes threshold. minLikes is also accepted.
170 |
# File 'lib/x_twitter_scraper/models/x/user_retrieve_tweets_params.rb', line 170 optional :min_faves, Integer |
#min_quotes ⇒ Integer?
Minimum quote count threshold.
176 |
# File 'lib/x_twitter_scraper/models/x/user_retrieve_tweets_params.rb', line 176 optional :min_quotes, Integer |
#min_replies ⇒ Integer?
Minimum replies threshold.
182 |
# File 'lib/x_twitter_scraper/models/x/user_retrieve_tweets_params.rb', line 182 optional :min_replies, Integer |
#min_retweets ⇒ Integer?
Minimum retweets threshold.
188 |
# File 'lib/x_twitter_scraper/models/x/user_retrieve_tweets_params.rb', line 188 optional :min_retweets, Integer |
#min_views ⇒ Integer?
Minimum view count threshold.
194 |
# File 'lib/x_twitter_scraper/models/x/user_retrieve_tweets_params.rb', line 194 optional :min_views, Integer |
#native_retweets ⇒ Boolean?
Only return native reposts.
200 |
# File 'lib/x_twitter_scraper/models/x/user_retrieve_tweets_params.rb', line 200 optional :native_retweets, XTwitterScraper::Internal::Type::Boolean |
#near ⇒ String?
Match a place name.
206 |
# File 'lib/x_twitter_scraper/models/x/user_retrieve_tweets_params.rb', line 206 optional :near, String |
#news ⇒ Boolean?
Only return news results.
212 |
# File 'lib/x_twitter_scraper/models/x/user_retrieve_tweets_params.rb', line 212 optional :news, XTwitterScraper::Internal::Type::Boolean |
#page_size ⇒ Integer?
Automatic pages accept 1-300 Tweets. Standard pages keep 1-100. Default 20. Continue while has_next_page is true. Deprecated aliases remain accepted.
219 |
# File 'lib/x_twitter_scraper/models/x/user_retrieve_tweets_params.rb', line 219 optional :page_size, Integer |
#quotes ⇒ Symbol, ...
Quote mode.
225 |
# File 'lib/x_twitter_scraper/models/x/user_retrieve_tweets_params.rb', line 225 optional :quotes, enum: -> { XTwitterScraper::X::UserRetrieveTweetsParams::Quotes } |
#quotes_of_tweet_id ⇒ String?
Only quotes of this tweet ID.
231 |
# File 'lib/x_twitter_scraper/models/x/user_retrieve_tweets_params.rb', line 231 optional :quotes_of_tweet_id, String |
#replies ⇒ Symbol, ...
Reply mode.
237 |
# File 'lib/x_twitter_scraper/models/x/user_retrieve_tweets_params.rb', line 237 optional :replies, enum: -> { XTwitterScraper::X::UserRetrieveTweetsParams::Replies } |
#retweets ⇒ Symbol, ...
Retweet mode.
243 |
# File 'lib/x_twitter_scraper/models/x/user_retrieve_tweets_params.rb', line 243 optional :retweets, enum: -> { XTwitterScraper::X::UserRetrieveTweetsParams::Retweets } |
#retweets_of_tweet_id ⇒ String?
Only retweets of this tweet ID.
249 |
# File 'lib/x_twitter_scraper/models/x/user_retrieve_tweets_params.rb', line 249 optional :retweets_of_tweet_id, String |
#safe ⇒ Boolean?
Enable the safe-search filter.
255 |
# File 'lib/x_twitter_scraper/models/x/user_retrieve_tweets_params.rb', line 255 optional :safe, XTwitterScraper::Internal::Type::Boolean |
#since_date ⇒ Date?
Start date in YYYY-MM-DD format.
261 |
# File 'lib/x_twitter_scraper/models/x/user_retrieve_tweets_params.rb', line 261 optional :since_date, Date |
#since_id ⇒ String?
Return Tweets newer than this Tweet ID.
267 |
# File 'lib/x_twitter_scraper/models/x/user_retrieve_tweets_params.rb', line 267 optional :since_id, String |
#source ⇒ String?
Match the source application.
273 |
# File 'lib/x_twitter_scraper/models/x/user_retrieve_tweets_params.rb', line 273 optional :source, String |
#to_user ⇒ String?
Filter replies sent to a username.
279 |
# File 'lib/x_twitter_scraper/models/x/user_retrieve_tweets_params.rb', line 279 optional :to_user, String |
#until_date ⇒ Date?
End date in YYYY-MM-DD format.
285 |
# File 'lib/x_twitter_scraper/models/x/user_retrieve_tweets_params.rb', line 285 optional :until_date, Date |
#url ⇒ String?
URL substring or domain filter.
291 |
# File 'lib/x_twitter_scraper/models/x/user_retrieve_tweets_params.rb', line 291 optional :url, String |
#verified_only ⇒ Boolean?
Only return tweets from verified authors.
297 |
# File 'lib/x_twitter_scraper/models/x/user_retrieve_tweets_params.rb', line 297 optional :verified_only, XTwitterScraper::Internal::Type::Boolean |
#within ⇒ String?
Set the radius for the near filter.
303 |
# File 'lib/x_twitter_scraper/models/x/user_retrieve_tweets_params.rb', line 303 optional :within, String |
#within_time ⇒ String?
Match Tweets inside a recent time window.
309 |
# File 'lib/x_twitter_scraper/models/x/user_retrieve_tweets_params.rb', line 309 optional :within_time, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/x_twitter_scraper/models/x/user_retrieve_tweets_params.rb', line 426
|
Instance Method Details
#to_hash ⇒ {
321 |
# File 'sig/x_twitter_scraper/models/x/user_retrieve_tweets_params.rbs', line 321
def to_hash: -> {
|